@@ -193,14 +193,15 @@ var NAVTREEINDEX1 =
 "funknown_8h.html#ae43645513f5c72529a3fb6c6d1e76b46":[3,0,9,8],
 "funknown_8h.html#aeab173beb18bb16a5737f9fbe0a45289":[3,0,9,29],
 "funknownimpl_8h.html":[3,0,10],
-"funknownimpl_8h.html#a0d0ab538662c2287caa62d394b13e5a9":[3,0,10,11],
-"funknownimpl_8h.html#a33de2f2ebaac4a7bbc9853bd215136b6":[3,0,10,14],
-"funknownimpl_8h.html#a3c8f4e584063f4ca3ecbaf01ac0335c9":[3,0,10,17],
-"funknownimpl_8h.html#a7c520b0f5be05c65bf838f57d0e87c14":[3,0,10,18],
-"funknownimpl_8h.html#aa97fe0c3b9d688a3e43da776dec431c6":[3,0,10,13],
-"funknownimpl_8h.html#ab00dcafdf662436bb9d9a9dd1f64d8d1":[3,0,10,15],
-"funknownimpl_8h.html#ac3e8ceb5f944fed679e545636429d1f3":[3,0,10,16],
-"funknownimpl_8h.html#ad7c3d8fc183de6c65cb7209c4edda8a7":[3,0,10,12],
+"funknownimpl_8h.html#a0d0ab538662c2287caa62d394b13e5a9":[3,0,10,12],
+"funknownimpl_8h.html#a33de2f2ebaac4a7bbc9853bd215136b6":[3,0,10,15],
+"funknownimpl_8h.html#a3c8f4e584063f4ca3ecbaf01ac0335c9":[3,0,10,19],
+"funknownimpl_8h.html#a68f6e121eb237b7f588f0036b056b43b":[3,0,10,16],
+"funknownimpl_8h.html#a7c520b0f5be05c65bf838f57d0e87c14":[3,0,10,20],
+"funknownimpl_8h.html#aa97fe0c3b9d688a3e43da776dec431c6":[3,0,10,14],
+"funknownimpl_8h.html#ab00dcafdf662436bb9d9a9dd1f64d8d1":[3,0,10,17],
+"funknownimpl_8h.html#ac3e8ceb5f944fed679e545636429d1f3":[3,0,10,18],
+"funknownimpl_8h.html#ad7c3d8fc183de6c65cb7209c4edda8a7":[3,0,10,13],
 "futils_8h.html":[3,0,11],
 "futils_8h.html#a0f480f7384f085c2606eff5f310ad194":[3,0,11,2],
 "futils_8h.html#a15c8c1bdcb98836c8074a36c9458c048":[3,0,11,9],
@@ -248,6 +249,5 @@ var NAVTREEINDEX1 =
 "group__pluginBase.html#ga4996ab6ef4807df458b8d49d47e10871":[0,0,14],
 "group__pluginGUI.html":[0,1],
 "hierarchy.html":[2,2],
-"ibstream_8h.html":[3,0,14],
-"icloneable_8h.html":[3,0,15]
+"ibstream_8h.html":[3,0,14]
 };
