@@ -44,6 +44,9 @@ var classSteinberg_1_1Vst_1_1HostCheckerController =
     [ "beginEditFromHost", "classSteinberg_1_1Vst_1_1HostCheckerController.html#af90af6cdca41f0ab7ac5d4387c28efd8", null ],
     [ "endEditFromHost", "classSteinberg_1_1Vst_1_1HostCheckerController.html#a480ad57ca0f00afd09fb0bb580865688", null ],
     [ "getParameterIDFromFunctionName", "classSteinberg_1_1Vst_1_1HostCheckerController.html#a44748e8541aeedc907128769c8bfd023", null ],
+    [ "queueOpened", "classSteinberg_1_1Vst_1_1HostCheckerController.html#a03c47a40142ada389fa7df3ab00f75c8", null ],
+    [ "queueClosed", "classSteinberg_1_1Vst_1_1HostCheckerController.html#a9cbc65f1d6c6bb0370a2cab22fda1d14", null ],
+    [ "onDataExchangeBlocksReceived", "classSteinberg_1_1Vst_1_1HostCheckerController.html#a1c5464feacdf2adcd6798bd672cc7414", null ],
     [ "editorAttached", "classSteinberg_1_1Vst_1_1HostCheckerController.html#ac055deeb5f5ddca6e9e030e06a2fac7c", null ],
     [ "editorRemoved", "classSteinberg_1_1Vst_1_1HostCheckerController.html#a893fe346bfbb357724bb3e4154ff80af", null ],
     [ "editorDestroyed", "classSteinberg_1_1Vst_1_1HostCheckerController.html#a3ca86a9534ad2bb3adb4f5e4d71d68a5", null ],
@@ -67,6 +70,7 @@ var classSteinberg_1_1Vst_1_1HostCheckerController =
     [ "mEditFromHost", "classSteinberg_1_1Vst_1_1HostCheckerController.html#a67e68448677c53ae9cb4511ffd08672f", null ],
     [ "threadChecker", "classSteinberg_1_1Vst_1_1HostCheckerController.html#af7bb4bec2475d18c304cc1263092e2cc", null ],
     [ "mNumKeyswitch", "classSteinberg_1_1Vst_1_1HostCheckerController.html#a7f1abbcdbf4f1b3df814931a9579539d", null ],
+    [ "dataExchange", "classSteinberg_1_1Vst_1_1HostCheckerController.html#aedf35e1b48a24686ea03fbd738a9fc7c", null ],
     [ "mScoreMap", "classSteinberg_1_1Vst_1_1HostCheckerController.html#aa306b40e142d5ff3b73da7931b116690", null ],
     [ "mProgressTimer", "classSteinberg_1_1Vst_1_1HostCheckerController.html#ac01c6fa61e7f27fc13e2a7c47c27f792", null ],
     [ "mProgressID", "classSteinberg_1_1Vst_1_1HostCheckerController.html#a7bd9dc65a3c41f9493abc417fa3342b1", null ],
