@@ -49,18 +49,20 @@ var NAVTREEINDEX1 =
 "classSteinberg_1_1Vst_1_1EditorSizeController.html#adaacfce4d25deb06a5971e726b913f53":[2,0,0,1,19,1],
 "classSteinberg_1_1Vst_1_1EditorSizeController.html#afb51d7f8c0a75b05503418a83a8e64ca":[2,0,0,1,19,6],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html":[2,0,0,1,20],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a06f291cb573e68c068f1575530e558a9":[2,0,0,1,20,60],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a03c47a40142ada389fa7df3ab00f75c8":[2,0,0,1,20,44],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a06f291cb573e68c068f1575530e558a9":[2,0,0,1,20,63],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a07afea77ec32591cdc9647baf9e5341c":[2,0,0,1,20,38],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a0e0358aa35e63cb6a96d4738b86a4cb2":[2,0,0,1,20,57],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a0e0358aa35e63cb6a96d4738b86a4cb2":[2,0,0,1,20,60],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a170e3042a5e695227c6931fba321debb":[2,0,0,1,20,21],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a182625d2b02683f36ec4aafa85911076":[2,0,0,1,20,58],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a2028ab458d2d798ff29b76a561306dc4":[2,0,0,1,20,59],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a182625d2b02683f36ec4aafa85911076":[2,0,0,1,20,61],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a1c5464feacdf2adcd6798bd672cc7414":[2,0,0,1,20,46],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a2028ab458d2d798ff29b76a561306dc4":[2,0,0,1,20,62],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a272e5d4c8e24f012573f9f5b11f7f569":[2,0,0,1,20,11],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a2994126983f1437424bafc780fa5919b":[2,0,0,1,20,50],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a2994126983f1437424bafc780fa5919b":[2,0,0,1,20,53],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a2acf420e46d11239fb9fb6f11447c41e":[2,0,0,1,20,5],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a375821f541e8b3338d3e2dbfae7433d8":[2,0,0,1,20,14],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a3ae1f7465f6641b01f76a098d0467b72":[2,0,0,1,20,15],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a3ca86a9534ad2bb3adb4f5e4d71d68a5":[2,0,0,1,20,46],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a3ca86a9534ad2bb3adb4f5e4d71d68a5":[2,0,0,1,20,49],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a44748e8541aeedc907128769c8bfd023":[2,0,0,1,20,43],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a480ad57ca0f00afd09fb0bb580865688":[2,0,0,1,20,42],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a487e1f5b80a28b511301f98dca4a5d0b":[2,0,0,1,20,34],
@@ -74,98 +76,106 @@ var NAVTREEINDEX1 =
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a60bbab8211ead54d50dbb672be410342":[2,0,0,1,20,20],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a65358ccb23d2c1b1ebc2e245eec0b824":[2,0,0,1,20,9],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a668ebd0a20787d498f761c94e34f6203":[2,0,0,1,20,22],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a67e68448677c53ae9cb4511ffd08672f":[2,0,0,1,20,64],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a67e68448677c53ae9cb4511ffd08672f":[2,0,0,1,20,67],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a7616efb48a8996352f9aefdd5d125924":[2,0,0,1,20,8],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a77ade9b8fc6f6bd01f8c225dda17a415":[2,0,0,1,20,30],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a7bd9dc65a3c41f9493abc417fa3342b1":[2,0,0,1,20,69],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a7bd9dc65a3c41f9493abc417fa3342b1":[2,0,0,1,20,73],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a7eb7bc3ca514ede042c8ad5d01414f4f":[2,0,0,1,20,6],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a7f1abbcdbf4f1b3df814931a9579539d":[2,0,0,1,20,66],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a7f1abbcdbf4f1b3df814931a9579539d":[2,0,0,1,20,69],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a7fd8b0bb033a680562d59922175ae088":[2,0,0,1,20,7],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a86f4dd968f780bf65369830c86adfa6a":[2,0,0,1,20,54],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a893fe346bfbb357724bb3e4154ff80af":[2,0,0,1,20,45],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a86f4dd968f780bf65369830c86adfa6a":[2,0,0,1,20,57],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a893fe346bfbb357724bb3e4154ff80af":[2,0,0,1,20,48],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a916c9d3245f4580b4effa6d977a64208":[2,0,0,1,20,13],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a9228db732b48ece8b5b734e69b979d10":[2,0,0,1,20,27],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a922bafd2d3b293f3718199dc804de0fe":[2,0,0,1,20,53],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a922bafd2d3b293f3718199dc804de0fe":[2,0,0,1,20,56],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a990e31f5d0bcc88d2c3a8e8c370a23ca":[2,0,0,1,20,25],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a9c53db76959c3f687ebf0a9e039b5523":[2,0,0,1,20,24],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a9cbc65f1d6c6bb0370a2cab22fda1d14":[2,0,0,1,20,45],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a9d48aa02feb98d52c054d5f4198fa7c9":[2,0,0,1,20,12],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a9ddae86018522bf2d708066884d89b3c":[2,0,0,1,20,61],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a9eab817373e53002e792dfa711ba80ca":[2,0,0,1,20,51],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a9ddae86018522bf2d708066884d89b3c":[2,0,0,1,20,64],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a9eab817373e53002e792dfa711ba80ca":[2,0,0,1,20,54],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#aa2fea25360b1f4824345acc423b1f8db":[2,0,0,1,20,19],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#aa306b40e142d5ff3b73da7931b116690":[2,0,0,1,20,67],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#aa306b40e142d5ff3b73da7931b116690":[2,0,0,1,20,71],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#aa946c9736e3aad934fd2d9b7b916cc43":[2,0,0,1,20,3],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#ab3ab4a69e656ba2673a228fb6e22e2bd":[2,0,0,1,20,23],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#abaafe2485a80cde3e71a231286208fdb":[2,0,0,1,20,63],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#abaafe2485a80cde3e71a231286208fdb":[2,0,0,1,20,66],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#abc366969b6b2e1cef34c221db92e806d":[2,0,0,1,20,35],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#abcb2607c54f1115af6663eed8d3cee25":[2,0,0,1,20,56],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#ac01c6fa61e7f27fc13e2a7c47c27f792":[2,0,0,1,20,68],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#ac055deeb5f5ddca6e9e030e06a2fac7c":[2,0,0,1,20,44],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#ac24758feb9e31f29d8ca5505bfac794e":[2,0,0,1,20,49],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#abcb2607c54f1115af6663eed8d3cee25":[2,0,0,1,20,59],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#ac01c6fa61e7f27fc13e2a7c47c27f792":[2,0,0,1,20,72],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#ac055deeb5f5ddca6e9e030e06a2fac7c":[2,0,0,1,20,47],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#ac24758feb9e31f29d8ca5505bfac794e":[2,0,0,1,20,52],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#acbe6bf21938011dad882eda62cfde163":[2,0,0,1,20,39],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#accb2b76127645a7a8ec171c7b220ce8d":[2,0,0,1,20,31],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#ace6060dd0ae226a8628785a44198e4b8":[2,0,0,1,20,70],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#ad6796376ef5cc027ed35c4b2dd170f41":[2,0,0,1,20,62],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#ace6060dd0ae226a8628785a44198e4b8":[2,0,0,1,20,74],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#ad6796376ef5cc027ed35c4b2dd170f41":[2,0,0,1,20,65],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#ad8535466d93aa534a40ae1244940cc52":[2,0,0,1,20,32],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#ae5ece0a3a8c6e4295d9adedb76d6edd8":[2,0,0,1,20,4],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#aeb78d794ce0bc5812c526a1cc2083d5d":[2,0,0,1,20,16],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#aedf0d687c00670ca351bd00b0b83f440":[2,0,0,1,20,52],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#aedf0d687c00670ca351bd00b0b83f440":[2,0,0,1,20,55],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#aedf35e1b48a24686ea03fbd738a9fc7c":[2,0,0,1,20,70],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#aee393393dc4dccf6e0b30a43380859b4":[2,0,0,1,20,28],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#af161b55b382c62c4868a760fff750cd0":[2,0,0,1,20,47],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#af2233bd23acc913cd10e4a30916e5dda":[2,0,0,1,20,48],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#af161b55b382c62c4868a760fff750cd0":[2,0,0,1,20,50],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#af2233bd23acc913cd10e4a30916e5dda":[2,0,0,1,20,51],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#af4d16dae99ff1010b80359cb70500e31":[2,0,0,1,20,36],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#af63358114b145c306987ac513b4e908d":[2,0,0,1,20,2],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#af7bb4bec2475d18c304cc1263092e2cc":[2,0,0,1,20,65],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#af7bb4bec2475d18c304cc1263092e2cc":[2,0,0,1,20,68],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#af7e79066204c7e0be05f30d63bcafb24":[2,0,0,1,20,1],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#af90af6cdca41f0ab7ac5d4387c28efd8":[2,0,0,1,20,41],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#afc56b230d780947eb7b477efb0e055f0":[2,0,0,1,20,55],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#afc56b230d780947eb7b477efb0e055f0":[2,0,0,1,20,58],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#aff61c36b9f383b24e53096d1ff4ca451":[2,0,0,1,20,26],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html":[2,0,0,1,21],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a068f99a30130361e5520332a2352269d":[2,0,0,1,21,40],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a139756f2008ef6b6df64b1d11a45afe3":[2,0,0,1,21,38],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a181b09f3964380df6a6c13669a4fe443":[2,0,0,1,21,20],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a068f99a30130361e5520332a2352269d":[2,0,0,1,21,44],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a139756f2008ef6b6df64b1d11a45afe3":[2,0,0,1,21,42],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a170e3042a5e695227c6931fba321debb":[2,0,0,1,21,17],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a181b09f3964380df6a6c13669a4fe443":[2,0,0,1,21,22],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a1bf4b1f878b98063c42b4cc344199386":[2,0,0,1,21,15],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a1c7a40be692f5ed7f009896af248beed":[2,0,0,1,21,9],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a272e5d4c8e24f012573f9f5b11f7f569":[2,0,0,1,21,2],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a2a13e09cc9ec3dd1b8617a38e3c07af5":[2,0,0,1,21,3],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a2abf85610a391b321822c95dbed515b0":[2,0,0,1,21,19],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a2abf85610a391b321822c95dbed515b0":[2,0,0,1,21,21],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a2f5f13092735afd906695953628a602e":[2,0,0,1,21,8],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a307db218f2f193eb1b8a148f3ec6234b":[2,0,0,1,21,44],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a3421da6fe5c880d8883071d8f07fcc38":[2,0,0,1,21,34],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a38897792d7e5b40cf6b1281ce8f9e587":[2,0,0,1,21,36],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a3d2c434afec1de448b62933f1819d988":[2,0,0,1,21,21],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a307db218f2f193eb1b8a148f3ec6234b":[2,0,0,1,21,48],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a3421da6fe5c880d8883071d8f07fcc38":[2,0,0,1,21,38],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a38897792d7e5b40cf6b1281ce8f9e587":[2,0,0,1,21,40],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a3d2c434afec1de448b62933f1819d988":[2,0,0,1,21,23],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a3e60369d6e79991573053e5e1d70fef3":[2,0,0,1,21,13],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a41f2f903ceb464691f853ec06269767b":[2,0,0,1,21,18],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a47c9a0666fc818febbfe5a760309af56":[2,0,0,1,21,25],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a41f2f903ceb464691f853ec06269767b":[2,0,0,1,21,20],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a47c9a0666fc818febbfe5a760309af56":[2,0,0,1,21,27],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a4dae123b5697706651d9ff20c9614f63":[2,0,0,1,21,1],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a5226097f06ed3b646babc1506b2aa46d":[2,0,0,1,21,50],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a59a4f257a9a19c184c509ac076d949ec":[2,0,0,1,21,28],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a60bbab8211ead54d50dbb672be410342":[2,0,0,1,21,6],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a658d09c308834934bb176a42ac9556d6":[2,0,0,1,21,28],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a658d09c308834934bb176a42ac9556d6":[2,0,0,1,21,31],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a6597f3049abfd875de6339005caacc5f":[2,0,0,1,21,0],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a67ca6088c256b04bb08a68badf4fcf00":[2,0,0,1,21,30],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a67ca6088c256b04bb08a68badf4fcf00":[2,0,0,1,21,34],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a6fe399148064f1f04eb3f6d71c1f966d":[2,0,0,1,21,10],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a754f2c1b5beff1179b96278344f1ef96":[2,0,0,1,21,4],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a8b5b7047992970f35052164dd7ae14b7":[2,0,0,1,21,43],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a8d173fe27c3c33e86138be563a23cfe4":[2,0,0,1,21,37],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a804638e2145a4f4e6fdcac6e2d959a1b":[2,0,0,1,21,49],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a8b5b7047992970f35052164dd7ae14b7":[2,0,0,1,21,47],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a8d173fe27c3c33e86138be563a23cfe4":[2,0,0,1,21,41],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a9228db732b48ece8b5b734e69b979d10":[2,0,0,1,21,11],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#aa09864e5d6f2062a14eb8ad2d1db297d":[2,0,0,1,21,45],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#aa09864e5d6f2062a14eb8ad2d1db297d":[2,0,0,1,21,51],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#aac50582d4f3f12401ae426cc31b33287":[2,0,0,1,21,7],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#ab2e0fa82b6165abab8cb9fe58b424b91":[2,0,0,1,21,46],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#ab6079e6b11197f30f7639f7c6bc169de":[2,0,0,1,21,39],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#ab6a0125edee61e33a460612e9c124e5d":[2,0,0,1,21,35],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#ab2e0fa82b6165abab8cb9fe58b424b91":[2,0,0,1,21,52],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#ab6079e6b11197f30f7639f7c6bc169de":[2,0,0,1,21,43],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#ab6a0125edee61e33a460612e9c124e5d":[2,0,0,1,21,39],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#abdb2b4992ff1c41eca948831dbe372b9":[2,0,0,1,21,16],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#ad041b268991632c5748992eaae4d3d34":[2,0,0,1,21,41],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#ad4712acdcb59fd76fa82ef5a24d7f05c":[2,0,0,1,21,22],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#abfe05e816fd9cefe91fe9223f94d49d9":[2,0,0,1,21,32],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#ad041b268991632c5748992eaae4d3d34":[2,0,0,1,21,45],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#ad4712acdcb59fd76fa82ef5a24d7f05c":[2,0,0,1,21,24],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#ad48c36f6210f722d195a93f68fb7dff4":[2,0,0,1,21,5],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#ad73b751920c09df1e9a2fd1ec37286c2":[2,0,0,1,21,33],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#ad990b6aadf707d63435e58dc9e339668":[2,0,0,1,21,24],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#ada49ef10ba1ab283b51c9feeeebaf8eb":[2,0,0,1,21,29],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#ae8562f8d887fad95cbf102cf73bf9222":[2,0,0,1,21,27],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#aea6b5378111b9c285895333620678821":[2,0,0,1,21,23],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#aebb3bc994a79d305c48d82da0b14d437":[2,0,0,1,21,31],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#aed02d7ec62e586feebfa60bfbf6d46a9":[2,0,0,1,21,32],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#ad73b751920c09df1e9a2fd1ec37286c2":[2,0,0,1,21,37],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#ad990b6aadf707d63435e58dc9e339668":[2,0,0,1,21,26],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#ada49ef10ba1ab283b51c9feeeebaf8eb":[2,0,0,1,21,33],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#adbcbdfd9061c4f951db444f60d358b12":[2,0,0,1,21,18],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#ae8562f8d887fad95cbf102cf73bf9222":[2,0,0,1,21,30],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#aea6b5378111b9c285895333620678821":[2,0,0,1,21,25],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#aebb3bc994a79d305c48d82da0b14d437":[2,0,0,1,21,35],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#aed02d7ec62e586feebfa60bfbf6d46a9":[2,0,0,1,21,36],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#aee393393dc4dccf6e0b30a43380859b4":[2,0,0,1,21,12],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#aee99fc996654dfbb3e371d85f925ce15":[2,0,0,1,21,17],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#af7bb4bec2475d18c304cc1263092e2cc":[2,0,0,1,21,42],
-"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#af97f6f6a592f1fab3c8f81af699a0b99":[2,0,0,1,21,26],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#aee99fc996654dfbb3e371d85f925ce15":[2,0,0,1,21,19],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#af7bb4bec2475d18c304cc1263092e2cc":[2,0,0,1,21,46],
+"classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#af97f6f6a592f1fab3c8f81af699a0b99":[2,0,0,1,21,29],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#af98a434f211539013a174bbe191156e3":[2,0,0,1,21,14],
 "classSteinberg_1_1Vst_1_1IDelayTestController.html":[2,0,0,1,5],
 "classSteinberg_1_1Vst_1_1IDelayTestController.html#a3348cedf7773d89835f8df92d8dfdec5":[2,0,0,1,5,0],
@@ -239,15 +249,5 @@ var NAVTREEINDEX1 =
 "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html#a5d93e889ab504c7e08356683094be8a5":[2,0,0,1,2,2,6],
 "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html#a9d48aa02feb98d52c054d5f4198fa7c9":[2,0,0,1,2,2,3],
 "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html#aaad58ca2f563a040d5bbee68f033971d":[2,0,0,1,2,2,11],
-"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html#abc366969b6b2e1cef34c221db92e806d":[2,0,0,1,2,2,8],
-"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html#accb2b76127645a7a8ec171c7b220ce8d":[2,0,0,1,2,2,5],
-"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html#aeb78d794ce0bc5812c526a1cc2083d5d":[2,0,0,1,2,2,4],
-"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html#af4d16dae99ff1010b80359cb70500e31":[2,0,0,1,2,2,9],
-"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html":[2,0,0,1,2,4],
-"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a0d13b05ef372806de086eec80526daae":[2,0,0,1,2,4,17],
-"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a272e5d4c8e24f012573f9f5b11f7f569":[2,0,0,1,2,4,5],
-"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a3310a1682cdcf572f5e22f59869b8e3c":[2,0,0,1,2,4,10],
-"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a4dae123b5697706651d9ff20c9614f63":[2,0,0,1,2,4,4],
-"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a55f180ed79364469774124be9d724160":[2,0,0,1,2,4,11],
-"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#a60aee36a21805e563d61242be6e7d8b0":[2,0,0,1,2,4,9]
+"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html#abc366969b6b2e1cef34c221db92e806d":[2,0,0,1,2,2,8]
 };
