@@ -1,11 +1,13 @@
 var searchData=
 [
   ['handler',['Handler',['../../vstsdk/structSteinberg_1_1Vst_1_1MPE_1_1Handler.html',1,'Steinberg::Vst::MPE']]],
+  ['hideiidbase',['HideIIDBase',['../../base/structSteinberg_1_1FUnknownImpl_1_1HideIIDBase.html',1,'Steinberg::FUnknownImpl']]],
   ['hostapplication',['HostApplication',['../../vstsdk/classSteinberg_1_1Vst_1_1HostApplication.html',1,'Steinberg::Vst']]],
   ['hostattributelist',['HostAttributeList',['../../vstsdk/exceptionSteinberg_1_1Vst_1_1HostAttributeList.html',1,'Steinberg::Vst']]],
   ['hostcheck',['HostCheck',['../classHostCheck.html',1,'']]],
   ['hostcheckercontroller',['HostCheckerController',['../classSteinberg_1_1Vst_1_1HostCheckerController.html',1,'Steinberg::Vst']]],
   ['hostcheckerprocessor',['HostCheckerProcessor',['../classSteinberg_1_1Vst_1_1HostCheckerProcessor.html',1,'Steinberg::Vst']]],
+  ['hostdataexchangehandler',['HostDataExchangeHandler',['../../vstsdk/structSteinberg_1_1Vst_1_1HostDataExchangeHandler.html',1,'Steinberg::Vst']]],
   ['hostmessage',['HostMessage',['../../vstsdk/exceptionSteinberg_1_1Vst_1_1HostMessage.html',1,'Steinberg::Vst']]],
   ['hostprocessdata',['HostProcessData',['../../vstsdk/classSteinberg_1_1Vst_1_1HostProcessData.html',1,'Steinberg::Vst']]]
 ];
