@@ -1,5 +1,7 @@
 var searchData=
 [
+  ['dataexchange_2ecpp',['dataexchange.cpp',['../../vstsdk/dataexchange_8cpp.html',1,'']]],
+  ['dataexchange_2eh',['dataexchange.h',['../../vstsdk/dataexchange_8h.html',1,'']]],
   ['doc_2eh',['doc.h',['../doc_8h.html',1,'']]],
   ['doc_5fpublic_5fsdk_2eh',['doc_public_sdk.h',['../../vstsdk/doc__public__sdk_8h.html',1,'']]],
   ['doc_5fpublic_5fsdk_5flimited_2eh',['doc_public_sdk_limited.h',['../../vstsdk/doc__public__sdk__limited_8h.html',1,'']]]
