@@ -8,6 +8,7 @@ var namespace_v_s_t_g_u_i =
     [ "Constants", "namespace_v_s_t_g_u_i_1_1_constants.html", null ],
     [ "Detail", "namespace_v_s_t_g_u_i_1_1_detail.html", null ],
     [ "EventPrivate", "namespace_v_s_t_g_u_i_1_1_event_private.html", null ],
+    [ "ExternalView", "namespace_v_s_t_g_u_i_1_1_external_view.html", "namespace_v_s_t_g_u_i_1_1_external_view" ],
     [ "PixelBuffer", "namespace_v_s_t_g_u_i_1_1_pixel_buffer.html", "namespace_v_s_t_g_u_i_1_1_pixel_buffer" ],
     [ "Standalone", "namespace_v_s_t_g_u_i_1_1_standalone.html", "namespace_v_s_t_g_u_i_1_1_standalone" ],
     [ "String", "namespace_v_s_t_g_u_i_1_1_string.html", null ],
@@ -23,6 +24,9 @@ var namespace_v_s_t_g_u_i =
     [ "CDrawContext", "class_v_s_t_g_u_i_1_1_c_draw_context.html", "class_v_s_t_g_u_i_1_1_c_draw_context" ],
     [ "ConcatClip", "struct_v_s_t_g_u_i_1_1_concat_clip.html", "struct_v_s_t_g_u_i_1_1_concat_clip" ],
     [ "CDrawMode", "struct_v_s_t_g_u_i_1_1_c_draw_mode.html", "struct_v_s_t_g_u_i_1_1_c_draw_mode" ],
+    [ "CExternalViewBaseImpl", "struct_v_s_t_g_u_i_1_1_c_external_view_base_impl.html", "struct_v_s_t_g_u_i_1_1_c_external_view_base_impl" ],
+    [ "CExternalView", "class_v_s_t_g_u_i_1_1_c_external_view.html", "class_v_s_t_g_u_i_1_1_c_external_view" ],
+    [ "CExternalControl", "class_v_s_t_g_u_i_1_1_c_external_control.html", "class_v_s_t_g_u_i_1_1_c_external_control" ],
     [ "CFileExtension", "class_v_s_t_g_u_i_1_1_c_file_extension.html", "class_v_s_t_g_u_i_1_1_c_file_extension" ],
     [ "CNewFileSelector", "exception_v_s_t_g_u_i_1_1_c_new_file_selector.html", "exception_v_s_t_g_u_i_1_1_c_new_file_selector" ],
     [ "GlobalFonts", "struct_v_s_t_g_u_i_1_1_global_fonts.html", "struct_v_s_t_g_u_i_1_1_global_fonts" ],
