@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['x',['x',['../class_v_s_t_g_u_i_1_1_c_bitmap_pixel_access.html#aae8a40a17c0be29c1f06ca6b4f9e2235',1,'VSTGUI::CBitmapPixelAccess::x()'],['../struct_v_s_t_g_u_i_1_1_c_point.html#a60ef7507ee817b2737b962ba07280c0e',1,'VSTGUI::CPoint::x()']]],
+  ['x',['x',['../class_v_s_t_g_u_i_1_1_c_bitmap_pixel_access.html#aae8a40a17c0be29c1f06ca6b4f9e2235',1,'VSTGUI::CBitmapPixelAccess::x()'],['../struct_v_s_t_g_u_i_1_1_c_point.html#a60ef7507ee817b2737b962ba07280c0e',1,'VSTGUI::CPoint::x()'],['../struct_v_s_t_g_u_i_1_1_external_view_1_1_int_point.html#a040359f45343ce6667f5c66fda5f50e3',1,'VSTGUI::ExternalView::IntPoint::x()']]],
   ['xmlchardata',['xmlCharData',['../class_v_s_t_g_u_i_1_1_xml_1_1_i_handler.html#a4c3bb1c16366f8d88b835344db6c2f93',1,'VSTGUI::Xml::IHandler']]],
   ['xmlcomment',['xmlComment',['../class_v_s_t_g_u_i_1_1_xml_1_1_i_handler.html#a91a76c183167ab1e3f899f8bb815529c',1,'VSTGUI::Xml::IHandler']]],
   ['xmlfile',['xmlFile',['../class_v_s_t_g_u_i_1_1_v_s_t3_editor.html#a4072a860c96114dbd253f33f473c6986',1,'VSTGUI::VST3Editor']]],
