@@ -6,5 +6,6 @@ var searchData=
   ['alphavalueanimation',['AlphaValueAnimation',['../class_v_s_t_g_u_i_1_1_animation_1_1_alpha_value_animation.html',1,'VSTGUI::Animation']]],
   ['animationsplashscreencreator',['AnimationSplashScreenCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_animation_splash_screen_creator.html',1,'VSTGUI::UIViewCreator']]],
   ['animator',['Animator',['../class_v_s_t_g_u_i_1_1_animation_1_1_animator.html',1,'VSTGUI::Animation']]],
-  ['animknobcreator',['AnimKnobCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_anim_knob_creator.html',1,'VSTGUI::UIViewCreator']]]
+  ['animknobcreator',['AnimKnobCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_anim_knob_creator.html',1,'VSTGUI::UIViewCreator']]],
+  ['autoanimationcreator',['AutoAnimationCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_auto_animation_creator.html',1,'VSTGUI::UIViewCreator']]]
 ];
