@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['x',['x',['../class_v_s_t_g_u_i_1_1_c_bitmap_pixel_access.html#aae8a40a17c0be29c1f06ca6b4f9e2235',1,'VSTGUI::CBitmapPixelAccess::x()'],['../struct_v_s_t_g_u_i_1_1_c_point.html#a60ef7507ee817b2737b962ba07280c0e',1,'VSTGUI::CPoint::x()']]],
+  ['x',['x',['../class_v_s_t_g_u_i_1_1_c_bitmap_pixel_access.html#aae8a40a17c0be29c1f06ca6b4f9e2235',1,'VSTGUI::CBitmapPixelAccess::x()'],['../struct_v_s_t_g_u_i_1_1_c_point.html#a60ef7507ee817b2737b962ba07280c0e',1,'VSTGUI::CPoint::x()'],['../struct_v_s_t_g_u_i_1_1_external_view_1_1_int_point.html#a040359f45343ce6667f5c66fda5f50e3',1,'VSTGUI::ExternalView::IntPoint::x()']]],
   ['xmlfile',['xmlFile',['../class_v_s_t_g_u_i_1_1_v_s_t3_editor.html#a4072a860c96114dbd253f33f473c6986',1,'VSTGUI::VST3Editor']]],
   ['xparam',['xParam',['../class_v_s_t_g_u_i_1_1_pad_controller.html#afa2da6948ddba9eb6088b899d7e681ed',1,'VSTGUI::PadController']]],
   ['xpos',['xpos',['../class_v_s_t_g_u_i_1_1_c_special_digit.html#a9ea1f84655e285403cea18e9a5d03d3e',1,'VSTGUI::CSpecialDigit']]]
