@@ -1,5 +1,10 @@
 var NAVTREEINDEX4 =
 {
+"group__speakerArrangements.html#gac672a7aa5cabd6a5d4c4441e6aadc925":[0,8,182],
+"group__speakerArrangements.html#gac69d39d0c88807b942731d970506c02d":[0,8,28],
+"group__speakerArrangements.html#gac777248ebd6fa592c82b7bcb78f9301e":[0,8,313],
+"group__speakerArrangements.html#gac7c590bd9642823b634c33a5fa3d6cfd":[0,8,141],
+"group__speakerArrangements.html#gac7d25b1cc65c51e76c225ae50c4116ba":[0,8,279],
 "group__speakerArrangements.html#gac847eadaa1938e45601af71cb37737b5":[0,8,227],
 "group__speakerArrangements.html#gac89dcac8a9acb594a3e406cc5241d650":[0,8,365],
 "group__speakerArrangements.html#gac91567b9c8119eb78d51f6cc398bd97f":[0,8,64],
@@ -145,44 +150,49 @@ var NAVTREEINDEX4 =
 "ivstaudioprocessor_8h.html#ae514554bd822c5370bf9496c70302e31af21cd390d9ad5f7929f3f0a3ab972e13":[3,0,4,9,0],
 "ivstaudioprocessor_8h.html#ae55c95a44e931e1cd78998c94bc65ee1":[3,0,4,6],
 "ivstaudioprocessor_8h.html#ga0017ff4ab459880956723e09c847188a":[3,0,4,11],
-"ivstaudioprocessor_8h.html#ga0091b72150adc715454c410d230127e9":[3,0,4,29],
-"ivstaudioprocessor_8h.html#ga01b7fd148c1e5aefa3ea548be3257e50":[3,0,4,25],
-"ivstaudioprocessor_8h.html#ga0280f4b9390e12bf4b4846515572694a":[3,0,4,19],
-"ivstaudioprocessor_8h.html#ga0759e804603c37125d02cbc3b091f03b":[3,0,4,23],
-"ivstaudioprocessor_8h.html#ga0ab3065d837d3ed2cb309b61e43e7590":[3,0,4,44],
-"ivstaudioprocessor_8h.html#ga1cbb72f7fd4c011b07e0a249228e54ac":[3,0,4,48],
-"ivstaudioprocessor_8h.html#ga2aea8d0a0d5d5e40680ce5260f52dafd":[3,0,4,21],
-"ivstaudioprocessor_8h.html#ga2dd44f3dc1709680a63b597bac817796":[3,0,4,32],
-"ivstaudioprocessor_8h.html#ga377e6c632bbed63329ad118e1d1f6780":[3,0,4,12],
-"ivstaudioprocessor_8h.html#ga4dd95a64193b078cc91d160ae39a95ed":[3,0,4,24],
-"ivstaudioprocessor_8h.html#ga5c37de66c8a6ede53f92d9ea117bbd50":[3,0,4,42],
-"ivstaudioprocessor_8h.html#ga658d80d06b44b28d34628e66c2f1e4e3":[3,0,4,28],
-"ivstaudioprocessor_8h.html#ga6a5beaeb94b8e0a215026ac95f44a6ab":[3,0,4,43],
-"ivstaudioprocessor_8h.html#ga6e00e778267b163458d145a6b6ac37b1":[3,0,4,20],
-"ivstaudioprocessor_8h.html#ga74b483d71fbc43888e605cfdf8b69bd3":[3,0,4,47],
-"ivstaudioprocessor_8h.html#ga793ad8a6c605423f8ca78e6bfacd8e22":[3,0,4,31],
+"ivstaudioprocessor_8h.html#ga0091b72150adc715454c410d230127e9":[3,0,4,34],
+"ivstaudioprocessor_8h.html#ga01b7fd148c1e5aefa3ea548be3257e50":[3,0,4,30],
+"ivstaudioprocessor_8h.html#ga0280f4b9390e12bf4b4846515572694a":[3,0,4,23],
+"ivstaudioprocessor_8h.html#ga0759e804603c37125d02cbc3b091f03b":[3,0,4,28],
+"ivstaudioprocessor_8h.html#ga0ab3065d837d3ed2cb309b61e43e7590":[3,0,4,49],
+"ivstaudioprocessor_8h.html#ga1cbb72f7fd4c011b07e0a249228e54ac":[3,0,4,53],
+"ivstaudioprocessor_8h.html#ga27b925ffb4f7d3da798f2b446fe06538":[3,0,4,12],
+"ivstaudioprocessor_8h.html#ga2aea8d0a0d5d5e40680ce5260f52dafd":[3,0,4,26],
+"ivstaudioprocessor_8h.html#ga2dd44f3dc1709680a63b597bac817796":[3,0,4,37],
+"ivstaudioprocessor_8h.html#ga377e6c632bbed63329ad118e1d1f6780":[3,0,4,14],
+"ivstaudioprocessor_8h.html#ga4dd95a64193b078cc91d160ae39a95ed":[3,0,4,29],
+"ivstaudioprocessor_8h.html#ga5a54a33f151d3d0068d43d377fbacaea":[3,0,4,13],
+"ivstaudioprocessor_8h.html#ga5c37de66c8a6ede53f92d9ea117bbd50":[3,0,4,47],
+"ivstaudioprocessor_8h.html#ga5d7f914faef6c2a37eea292a7b16c76f":[3,0,4,21],
+"ivstaudioprocessor_8h.html#ga658d80d06b44b28d34628e66c2f1e4e3":[3,0,4,33],
+"ivstaudioprocessor_8h.html#ga6a5beaeb94b8e0a215026ac95f44a6ab":[3,0,4,48],
+"ivstaudioprocessor_8h.html#ga6e00e778267b163458d145a6b6ac37b1":[3,0,4,24],
+"ivstaudioprocessor_8h.html#ga74b483d71fbc43888e605cfdf8b69bd3":[3,0,4,52],
+"ivstaudioprocessor_8h.html#ga793ad8a6c605423f8ca78e6bfacd8e22":[3,0,4,36],
+"ivstaudioprocessor_8h.html#ga7cc4c653b53d167ebf833dc4bcd373ba":[3,0,4,16],
 "ivstaudioprocessor_8h.html#ga81395ffc74210c6b129ac5c1ad0f0450":[3,0,4,10],
-"ivstaudioprocessor_8h.html#ga9584914ab8362461d1bb4bac52ab9fd9":[3,0,4,14],
-"ivstaudioprocessor_8h.html#ga96b0fa2b93633f94d256d0926a23216f":[3,0,4,45],
-"ivstaudioprocessor_8h.html#ga9dbf945372efb065d5f47af0aed0c498":[3,0,4,15],
-"ivstaudioprocessor_8h.html#gaa5ff5ac3ea4de85f61375ed04b2ab88a":[3,0,4,39],
-"ivstaudioprocessor_8h.html#gaadec73a763ae5856f94a1d0ad1335d58":[3,0,4,35],
-"ivstaudioprocessor_8h.html#gab1fff222e0c2b65ce6574afa48e3b838":[3,0,4,40],
-"ivstaudioprocessor_8h.html#gab2264c85ad07f983f365ca1c53489fe3":[3,0,4,22],
-"ivstaudioprocessor_8h.html#gab77fa9595f5503b0d5a49407e1a918c7":[3,0,4,26],
-"ivstaudioprocessor_8h.html#gabd5da3c6aa4168e82cf36eb2c42fac1e":[3,0,4,46],
-"ivstaudioprocessor_8h.html#gac380562898ec7144f4e0ee3b4baa6aa3":[3,0,4,30],
-"ivstaudioprocessor_8h.html#gac5a7bb9551dc86a93bc764efef832164":[3,0,4,41],
-"ivstaudioprocessor_8h.html#gad632f4944a960678d6ff9b3886c878db":[3,0,4,18],
-"ivstaudioprocessor_8h.html#gad8da16bef223355cc58d3b469f876b33":[3,0,4,13],
-"ivstaudioprocessor_8h.html#gadceab87ecf367542d41be60acbdf1f6a":[3,0,4,33],
-"ivstaudioprocessor_8h.html#gadf71323f9881f84038a18a55f9c5693b":[3,0,4,34],
-"ivstaudioprocessor_8h.html#gae0aa5ea7deb453d05ae4a38612d30868":[3,0,4,37],
-"ivstaudioprocessor_8h.html#gaf0d4b7073ef26a60cedee77e04e9f94f":[3,0,4,38],
-"ivstaudioprocessor_8h.html#gaf145d8e7f4ba5cf0b6f8d1373647451f":[3,0,4,16],
-"ivstaudioprocessor_8h.html#gaf9b7f8cfe416744097bfcddfdcced2e6":[3,0,4,27],
-"ivstaudioprocessor_8h.html#gafe3ff646d102a4209512d6cda3b62ac4":[3,0,4,17],
-"ivstaudioprocessor_8h.html#gaffed7482d7d1551379ad26515f4816ef":[3,0,4,36],
+"ivstaudioprocessor_8h.html#ga9584914ab8362461d1bb4bac52ab9fd9":[3,0,4,17],
+"ivstaudioprocessor_8h.html#ga96b0fa2b93633f94d256d0926a23216f":[3,0,4,50],
+"ivstaudioprocessor_8h.html#ga9dbf945372efb065d5f47af0aed0c498":[3,0,4,18],
+"ivstaudioprocessor_8h.html#gaa5ff5ac3ea4de85f61375ed04b2ab88a":[3,0,4,44],
+"ivstaudioprocessor_8h.html#gaadec73a763ae5856f94a1d0ad1335d58":[3,0,4,40],
+"ivstaudioprocessor_8h.html#gab1fff222e0c2b65ce6574afa48e3b838":[3,0,4,45],
+"ivstaudioprocessor_8h.html#gab2264c85ad07f983f365ca1c53489fe3":[3,0,4,27],
+"ivstaudioprocessor_8h.html#gab77fa9595f5503b0d5a49407e1a918c7":[3,0,4,31],
+"ivstaudioprocessor_8h.html#gabd5da3c6aa4168e82cf36eb2c42fac1e":[3,0,4,51],
+"ivstaudioprocessor_8h.html#gac380562898ec7144f4e0ee3b4baa6aa3":[3,0,4,35],
+"ivstaudioprocessor_8h.html#gac5a7bb9551dc86a93bc764efef832164":[3,0,4,46],
+"ivstaudioprocessor_8h.html#gad632f4944a960678d6ff9b3886c878db":[3,0,4,22],
+"ivstaudioprocessor_8h.html#gad8da16bef223355cc58d3b469f876b33":[3,0,4,15],
+"ivstaudioprocessor_8h.html#gada3df3cb9ee2283e1dbae231d9d18644":[3,0,4,25],
+"ivstaudioprocessor_8h.html#gadceab87ecf367542d41be60acbdf1f6a":[3,0,4,38],
+"ivstaudioprocessor_8h.html#gadf71323f9881f84038a18a55f9c5693b":[3,0,4,39],
+"ivstaudioprocessor_8h.html#gae0aa5ea7deb453d05ae4a38612d30868":[3,0,4,42],
+"ivstaudioprocessor_8h.html#gaf0d4b7073ef26a60cedee77e04e9f94f":[3,0,4,43],
+"ivstaudioprocessor_8h.html#gaf145d8e7f4ba5cf0b6f8d1373647451f":[3,0,4,19],
+"ivstaudioprocessor_8h.html#gaf9b7f8cfe416744097bfcddfdcced2e6":[3,0,4,32],
+"ivstaudioprocessor_8h.html#gafe3ff646d102a4209512d6cda3b62ac4":[3,0,4,20],
+"ivstaudioprocessor_8h.html#gaffed7482d7d1551379ad26515f4816ef":[3,0,4,41],
 "ivstautomationstate_8h.html":[3,0,5],
 "ivstchannelcontextinfo_8h.html":[3,0,6],
 "ivstchannelcontextinfo_8h.html#a0631a9689c90dab1e9267681bc3d351a":[3,0,6,6],
@@ -239,15 +249,5 @@ var NAVTREEINDEX4 =
 "ivsteditcontroller_8h.html#a17867782006f9fdb2b72c16b0420bed5aa11fe6e24349c6d2f7e0035dbc01c10b":[3,0,10,12,6],
 "ivsteditcontroller_8h.html#a17867782006f9fdb2b72c16b0420bed5ab9d170d239305a60a6632d2224dd0cc9":[3,0,10,12,10],
 "ivsteditcontroller_8h.html#a17867782006f9fdb2b72c16b0420bed5abf3d2b0a3519f44507b88691c0e6555e":[3,0,10,12,7],
-"ivsteditcontroller_8h.html#a17867782006f9fdb2b72c16b0420bed5ae2e3ed4527f88e577a2aeb595bd853fd":[3,0,10,12,5],
-"ivsteditcontroller_8h.html#a17867782006f9fdb2b72c16b0420bed5af5308f6f5d92e718ccbd4cb0ca414907":[3,0,10,12,4],
-"ivsteditcontroller_8h.html#a49d6f6f53c7630ea334474e9998c0a99":[3,0,10,10],
-"ivsteditcontroller_8h.html#aaa62c4c32f0270a908eb20c7c7124dfc":[3,0,10,14],
-"ivsteditcontroller_8h.html#aaf58222f7d58268cdbe5849fd0670b39":[3,0,10,13],
-"ivsteditcontroller_8h.html#aaf58222f7d58268cdbe5849fd0670b39a248b4aaa79db639d5610c6e632269d7a":[3,0,10,13,2],
-"ivsteditcontroller_8h.html#aaf58222f7d58268cdbe5849fd0670b39a261944b6b143c6fc78fa1e9c783200ea":[3,0,10,13,0],
-"ivsteditcontroller_8h.html#aaf58222f7d58268cdbe5849fd0670b39a98a7d7b1f331414876a55df149340e1e":[3,0,10,13,1],
-"ivsteditcontroller_8h.html#ga98965411c9e542b7c2a99a46c8c1dfa2":[3,0,10,11],
-"ivstevents_8h.html":[3,0,11],
-"ivstevents_8h.html#aa00940542b032ef188a88bda982bd36a":[3,0,11,9]
+"ivsteditcontroller_8h.html#a17867782006f9fdb2b72c16b0420bed5ae2e3ed4527f88e577a2aeb595bd853fd":[3,0,10,12,5]
 };
