@@ -1,5 +1,15 @@
 var NAVTREEINDEX5 =
 {
+"ivsteditcontroller_8h.html#a17867782006f9fdb2b72c16b0420bed5af5308f6f5d92e718ccbd4cb0ca414907":[3,0,10,12,4],
+"ivsteditcontroller_8h.html#a49d6f6f53c7630ea334474e9998c0a99":[3,0,10,10],
+"ivsteditcontroller_8h.html#aaa62c4c32f0270a908eb20c7c7124dfc":[3,0,10,14],
+"ivsteditcontroller_8h.html#aaf58222f7d58268cdbe5849fd0670b39":[3,0,10,13],
+"ivsteditcontroller_8h.html#aaf58222f7d58268cdbe5849fd0670b39a248b4aaa79db639d5610c6e632269d7a":[3,0,10,13,2],
+"ivsteditcontroller_8h.html#aaf58222f7d58268cdbe5849fd0670b39a261944b6b143c6fc78fa1e9c783200ea":[3,0,10,13,0],
+"ivsteditcontroller_8h.html#aaf58222f7d58268cdbe5849fd0670b39a98a7d7b1f331414876a55df149340e1e":[3,0,10,13,1],
+"ivsteditcontroller_8h.html#ga98965411c9e542b7c2a99a46c8c1dfa2":[3,0,10,11],
+"ivstevents_8h.html":[3,0,11],
+"ivstevents_8h.html#aa00940542b032ef188a88bda982bd36a":[3,0,11,9],
 "ivstevents_8h.html#aa00940542b032ef188a88bda982bd36aa522b98801c4416f664488eb65aa33ab6":[3,0,11,9,0],
 "ivstevents_8h.html#aa00940542b032ef188a88bda982bd36aab3bd1010e0ee8b8817e14a6c64b3997f":[3,0,11,9,1],
 "ivsthostapplication_8h.html":[3,0,12],
@@ -224,30 +234,20 @@ var NAVTREEINDEX5 =
 "ivsttestplugprovider_8h.html":[3,0,26],
 "ivstunits_8h.html":[3,0,27],
 "modules.html":[0],
-"namespaceSteinberg_1_1Vst.html":[2,0,0,1],
 "namespaceSteinberg_1_1Vst.html":[1,0,0,1],
+"namespaceSteinberg_1_1Vst.html":[2,0,0,1],
 "namespaceSteinberg_1_1Vst_1_1Attributes.html":[1,0,0,1,6],
 "namespaceSteinberg_1_1Vst_1_1Attributes.html":[2,0,0,1,6],
 "namespaceSteinberg_1_1Vst_1_1AttributesFlags.html":[1,0,0,1,9],
 "namespaceSteinberg_1_1Vst_1_1AttributesFlags.html":[2,0,0,1,9],
-"namespaceSteinberg_1_1Vst_1_1AttributesFunction.html":[2,0,0,1,7],
 "namespaceSteinberg_1_1Vst_1_1AttributesFunction.html":[1,0,0,1,7],
+"namespaceSteinberg_1_1Vst_1_1AttributesFunction.html":[2,0,0,1,7],
 "namespaceSteinberg_1_1Vst_1_1AttributesStyle.html":[1,0,0,1,8],
 "namespaceSteinberg_1_1Vst_1_1AttributesStyle.html":[2,0,0,1,8],
 "namespaceSteinberg_1_1Vst_1_1ChannelContext.html":[1,0,0,1,1],
 "namespaceSteinberg_1_1Vst_1_1ChannelContext.html":[2,0,0,1,1],
-"namespaceSteinberg_1_1Vst_1_1CurveType.html":[1,0,0,1,5],
 "namespaceSteinberg_1_1Vst_1_1CurveType.html":[2,0,0,1,5],
+"namespaceSteinberg_1_1Vst_1_1CurveType.html":[1,0,0,1,5],
 "namespaceSteinberg_1_1Vst_1_1FunctionNameType.html":[1,0,0,1,3],
-"namespaceSteinberg_1_1Vst_1_1FunctionNameType.html":[2,0,0,1,3],
-"namespaceSteinberg_1_1Vst_1_1LayerType.html":[1,0,0,1,4],
-"namespaceSteinberg_1_1Vst_1_1LayerType.html":[2,0,0,1,4],
-"namespaceSteinberg_1_1Vst_1_1MusicalCharacter.html":[2,0,0,1,14],
-"namespaceSteinberg_1_1Vst_1_1MusicalCharacter.html":[1,0,0,1,14],
-"namespaceSteinberg_1_1Vst_1_1MusicalInstrument.html":[1,0,0,1,12],
-"namespaceSteinberg_1_1Vst_1_1MusicalInstrument.html":[2,0,0,1,12],
-"namespaceSteinberg_1_1Vst_1_1MusicalStyle.html":[1,0,0,1,13],
-"namespaceSteinberg_1_1Vst_1_1MusicalStyle.html":[2,0,0,1,13],
-"namespaceSteinberg_1_1Vst_1_1PlugType.html":[1,0,0,1,0],
-"namespaceSteinberg_1_1Vst_1_1PlugType.html":[2,0,0,1,0]
+"namespaceSteinberg_1_1Vst_1_1FunctionNameType.html":[2,0,0,1,3]
 };
