@@ -1,5 +1,15 @@
 var NAVTREEINDEX6 =
 {
+"namespaceSteinberg_1_1Vst_1_1LayerType.html":[1,0,0,1,4],
+"namespaceSteinberg_1_1Vst_1_1LayerType.html":[2,0,0,1,4],
+"namespaceSteinberg_1_1Vst_1_1MusicalCharacter.html":[2,0,0,1,14],
+"namespaceSteinberg_1_1Vst_1_1MusicalCharacter.html":[1,0,0,1,14],
+"namespaceSteinberg_1_1Vst_1_1MusicalInstrument.html":[1,0,0,1,12],
+"namespaceSteinberg_1_1Vst_1_1MusicalInstrument.html":[2,0,0,1,12],
+"namespaceSteinberg_1_1Vst_1_1MusicalStyle.html":[1,0,0,1,13],
+"namespaceSteinberg_1_1Vst_1_1MusicalStyle.html":[2,0,0,1,13],
+"namespaceSteinberg_1_1Vst_1_1PlugType.html":[1,0,0,1,0],
+"namespaceSteinberg_1_1Vst_1_1PlugType.html":[2,0,0,1,0],
 "namespaceSteinberg_1_1Vst_1_1PresetAttributes.html":[1,0,0,1,10],
 "namespaceSteinberg_1_1Vst_1_1PresetAttributes.html":[2,0,0,1,10],
 "namespaceSteinberg_1_1Vst_1_1SpeakerArr.html":[1,0,0,1,15],
@@ -8,8 +18,8 @@ var NAVTREEINDEX6 =
 "namespaceSteinberg_1_1Vst_1_1StateType.html":[2,0,0,1,11],
 "namespaceSteinberg_1_1Vst_1_1ViewType.html":[1,0,0,1,2],
 "namespaceSteinberg_1_1Vst_1_1ViewType.html":[2,0,0,1,2],
-"namespacemembers.html":[1,1,0],
 "namespacemembers.html":[1,1,0,0],
+"namespacemembers.html":[1,1,0],
 "namespacemembers_0x62.html":[1,1,0,1],
 "namespacemembers_0x63.html":[1,1,0,2],
 "namespacemembers_0x64.html":[1,1,0,3],
@@ -35,15 +45,15 @@ var NAVTREEINDEX6 =
 "pages.html":[],
 "structSteinberg_1_1ViewRect.html":[0,9,2],
 "structSteinberg_1_1ViewRect.html#a056cba400137ab9db43fdc7da2132a40":[0,9,2,9],
-"structSteinberg_1_1ViewRect.html#a37bfccc82fc5f189f4de5ed444a38ed2":[0,9,2,3],
 "structSteinberg_1_1ViewRect.html#a37bfccc82fc5f189f4de5ed444a38ed2":[0,9,2,5],
+"structSteinberg_1_1ViewRect.html#a37bfccc82fc5f189f4de5ed444a38ed2":[0,9,2,3],
 "structSteinberg_1_1ViewRect.html#a5aea1a81a05b75bedc5d4c40373592d1":[0,9,2,7],
 "structSteinberg_1_1ViewRect.html#a773c879226336b9859a3dec0a7f8e6ca":[0,9,2,8],
-"structSteinberg_1_1ViewRect.html#a945705dce8930a0dc58dcb044729b1c0":[0,9,2,2],
 "structSteinberg_1_1ViewRect.html#a945705dce8930a0dc58dcb044729b1c0":[0,9,2,4],
+"structSteinberg_1_1ViewRect.html#a945705dce8930a0dc58dcb044729b1c0":[0,9,2,2],
 "structSteinberg_1_1ViewRect.html#ae08ef45a841fb76eef2ed11f7f6661ad":[0,9,2,6],
-"structSteinberg_1_1ViewRect.html#afcdde0147792d1103d06537c37e59ef0":[0,9,2,1],
 "structSteinberg_1_1ViewRect.html#afcdde0147792d1103d06537c37e59ef0":[0,9,2,0],
+"structSteinberg_1_1ViewRect.html#afcdde0147792d1103d06537c37e59ef0":[0,9,2,1],
 "structSteinberg_1_1Vst_1_1AudioBusBuffers.html":[2,0,0,1,19],
 "structSteinberg_1_1Vst_1_1AudioBusBuffers.html#a0bbcd9a3e75d01b547097c91f9f659cf":[2,0,0,1,19,4],
 "structSteinberg_1_1Vst_1_1AudioBusBuffers.html#a2c73b926e22ddb05193b6edd16a008f8":[2,0,0,1,19,2],
@@ -239,15 +249,5 @@ var NAVTREEINDEX6 =
 "structSteinberg_1_1Vst_1_1ProcessContext.html#a8a97acf6c5676d31de6ceac2483ecf3a":[2,0,0,1,81,13],
 "structSteinberg_1_1Vst_1_1ProcessContext.html#a9081efe983722f59098a542b149bb07f":[2,0,0,1,81,7],
 "structSteinberg_1_1Vst_1_1ProcessContext.html#aa442da3063c73885d2f386deb479d870":[2,0,0,1,81,5],
-"structSteinberg_1_1Vst_1_1ProcessContext.html#ac7c0bf22aeb016dfe8143bd1f261585a":[2,0,0,1,81,11],
-"structSteinberg_1_1Vst_1_1ProcessContext.html#af46e5ad510319f6dd5687519ae47c76b":[2,0,0,1,81,14],
-"structSteinberg_1_1Vst_1_1ProcessContext.html#afc2ff5534156a67b58ead0eb0370b45a":[2,0,0,1,81,9],
-"structSteinberg_1_1Vst_1_1ProcessContext.html#aff2f6d52166217d13f9b2072c9e67c13":[2,0,0,1,81,10],
-"structSteinberg_1_1Vst_1_1ProcessData.html":[2,0,0,1,20],
-"structSteinberg_1_1Vst_1_1ProcessData.html#a0f85383979879cac64621f4ffb25cae0":[2,0,0,1,20,1],
-"structSteinberg_1_1Vst_1_1ProcessData.html#a100f97803b72565daedee80e34bbb7f0":[2,0,0,1,20,0],
-"structSteinberg_1_1Vst_1_1ProcessData.html#a1338255f88bad5cf4fb714c71f92b61a":[2,0,0,1,20,5],
-"structSteinberg_1_1Vst_1_1ProcessData.html#a28fedbd059e95b0d0c0ebfe3b081b4e5":[2,0,0,1,20,7],
-"structSteinberg_1_1Vst_1_1ProcessData.html#a2c04010f689fda04c547aea84d894b3f":[2,0,0,1,20,8],
-"structSteinberg_1_1Vst_1_1ProcessData.html#a55878a119a399f3e35f46272faac21b5":[2,0,0,1,20,10]
+"structSteinberg_1_1Vst_1_1ProcessContext.html#ac7c0bf22aeb016dfe8143bd1f261585a":[2,0,0,1,81,11]
 };
