@@ -40,8 +40,12 @@ var searchData=
   ['addunit',['addUnit',['../../vstsdk/classSteinberg_1_1Vst_1_1EditControllerEx1.html#a8fbc2c8dab1b94795bcaf35473fabdfc',1,'Steinberg::Vst::EditControllerEx1']]],
   ['adopt',['adopt',['../../base/classSteinberg_1_1IPtr.html#a7bb3f6e7f2c0de237814076dfe445742',1,'Steinberg::FUnknownPtr']]],
   ['advance',['advance',['../../vstsdk/structSteinberg_1_1Vst_1_1SampleAccurate_1_1Parameter.html#a0a1eb92e8f90285d812b91b9031be7bd',1,'Steinberg::Vst::SampleAccurate::Parameter::advance(int32 numSamples) noexcept'],['../../vstsdk/structSteinberg_1_1Vst_1_1SampleAccurate_1_1Parameter.html#a24114f6f1d82cd432747762041387fab',1,'Steinberg::Vst::SampleAccurate::Parameter::advance(int32 numSamples, Proc p) noexcept']]],
+  ['alignedalloc_2eh',['alignedalloc.h',['../../vstsdk/alignedalloc_8h.html',1,'']]],
+  ['alignment',['alignment',['../../vstsdk/structSteinberg_1_1Vst_1_1DataExchangeHandler_1_1Config.html#ae60a9b82d7097942c8d2e3a5d434a897',1,'Steinberg::Vst::DataExchangeHandler::Config']]],
   ['allocatemessage',['allocateMessage',['../../vstsdk/classSteinberg_1_1Vst_1_1ComponentBase.html#aae7bbbf07353224bb0ba77a091b87d33',1,'Steinberg::Vst::AudioEffect::allocateMessage()'],['../namespaceSteinberg_1_1Vst.html#a80587fa5437b07a138473ce70d3b7dda',1,'Steinberg::Vst::allocateMessage()']]],
   ['allocationerror',['allocationError',['../../vstsdk/classSteinberg_1_1MemoryStream.html#a1bfaf9acdd950aac257085ff792dfedb',1,'Steinberg::MemoryStream']]],
+  ['allowallocatesize',['allowAllocateSize',['../../vstsdk/structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost.html#a34e686050e3477b842a5589d171a57be',1,'Steinberg::Vst::IDataExchangeHandlerHost']]],
+  ['allowqueuelistresize',['allowQueueListResize',['../../vstsdk/structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost.html#ad0fba34c6a580a12c6bbd572c7951f01',1,'Steinberg::Vst::IDataExchangeHandlerHost']]],
   ['append',['append',['../../base/classSteinberg_1_1UString.html#a014ae12c2b6d6f3042855c5e411c0445',1,'Steinberg::UString']]],
   ['appendstring',['appendString',['../../vstsdk/classSteinberg_1_1Vst_1_1StringListParameter.html#a57131772fda4fd320e3d8cd7c7c981b7',1,'Steinberg::Vst::StringListParameter']]],
   ['application_3adidfinishlaunchingwithoptions_3a',['application:didFinishLaunchingWithOptions:',['../../vstsdk/interfaceVSTInterAppAudioAppDelegateBase.html#af02564ed60997f25d5140e48a12124a7',1,'VSTInterAppAudioAppDelegateBase']]],
@@ -86,17 +90,17 @@ var searchData=
   ['aucarbonview_2emm',['aucarbonview.mm',['../../vstsdk/aucarbonview_8mm.html',1,'']]],
   ['aucocoaview_2eh',['aucocoaview.h',['../../vstsdk/aucocoaview_8h.html',1,'']]],
   ['aucocoaview_2emm',['aucocoaview.mm',['../../vstsdk/aucocoaview_8mm.html',1,'']]],
-  ['audiobuffer',['AudioBuffer',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBuffer.html',1,'Steinberg::Vst']]],
   ['audiobuffer',['AudioBuffer',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBuffer.html#a53af24182f3165ed15b4f434d7088b53',1,'Steinberg::Vst::AudioBuffer']]],
+  ['audiobuffer',['AudioBuffer',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBuffer.html',1,'Steinberg::Vst']]],
   ['audiobuffer_3c_20t_20_3e',['AudioBuffer&lt; T &gt;',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBuffer.html',1,'Steinberg::Vst']]],
   ['audiobuffers_2eh',['audiobuffers.h',['../../vstsdk/audiobuffers_8h.html',1,'']]],
-  ['audiobus',['AudioBus',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBus.html#aa88e9bd8e9d969a00f0bd035a03c359f',1,'Steinberg::Vst::AudioBus']]],
   ['audiobus',['AudioBus',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBus.html',1,'Steinberg::Vst']]],
-  ['audiobusbuffers',['AudioBusBuffers',['../structSteinberg_1_1Vst_1_1AudioBusBuffers.html#a9b1b17da17d0a50b82b03273caae2b8b',1,'Steinberg::Vst::AudioBusBuffers']]],
+  ['audiobus',['AudioBus',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBus.html#aa88e9bd8e9d969a00f0bd035a03c359f',1,'Steinberg::Vst::AudioBus']]],
   ['audiobusbuffers',['AudioBusBuffers',['../structSteinberg_1_1Vst_1_1AudioBusBuffers.html',1,'Steinberg::Vst']]],
+  ['audiobusbuffers',['AudioBusBuffers',['../structSteinberg_1_1Vst_1_1AudioBusBuffers.html#a9b1b17da17d0a50b82b03273caae2b8b',1,'Steinberg::Vst::AudioBusBuffers']]],
   ['audiodefaults',['AudioDefaults',['../../vstsdk/classSteinberg_1_1Vst_1_1TestEnh.html#aeeab75fa34b77d026422bf02ea2a7716',1,'Steinberg::Vst::TestEnh']]],
-  ['audioeffect',['AudioEffect',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html#a491f4bb6a5f726c520667832df4b9a14',1,'Steinberg::Vst::AudioEffect::AudioEffect()'],['../../vstsdk/classSteinberg_1_1Vst_1_1TestEnh.html#a13adc72f47daf6dc87f28e58b52c72d0',1,'Steinberg::Vst::TestEnh::audioEffect()']]],
   ['audioeffect',['AudioEffect',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html',1,'Steinberg::Vst']]],
+  ['audioeffect',['AudioEffect',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html#a491f4bb6a5f726c520667832df4b9a14',1,'Steinberg::Vst::AudioEffect::AudioEffect()'],['../../vstsdk/classSteinberg_1_1Vst_1_1TestEnh.html#a13adc72f47daf6dc87f28e58b52c72d0',1,'Steinberg::Vst::TestEnh::audioEffect()']]],
   ['audioinputs',['audioInputs',['../../vstsdk/classSteinberg_1_1Vst_1_1Component.html#a3bb91eeb91df8bc7446713244ae11bac',1,'Steinberg::Vst::AudioEffect::audioInputs()'],['../../vstsdk/classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a4918c0fce4a78d193457bcca2a6d4cca',1,'Steinberg::Vst::SingleComponentEffect::audioInputs()']]],
   ['audioio_2eh',['AudioIO.h',['../../vstsdk/AudioIO_8h.html',1,'']]],
   ['audioio_2emm',['AudioIO.mm',['../../vstsdk/AudioIO_8mm.html',1,'']]],
