@@ -70,7 +70,7 @@ var searchData=
   ['pluginterfacesupport_2eh',['pluginterfacesupport.h',['../../vstsdk/pluginterfacesupport_8h.html',1,'']]],
   ['pluginview_2eh',['pluginview.h',['../../vstsdk/pluginview_8h.html',1,'']]],
   ['plugisglobal',['plugIsGlobal',['../../vstsdk/classSteinberg_1_1Vst_1_1PlugProvider.html#a6249cbd10d897a88d111a89c2ca6b6b6',1,'Steinberg::Vst::PlugProvider']]],
-  ['plugprovider',['PlugProvider',['../../vstsdk/classSteinberg_1_1Vst_1_1PlugProvider.html#a020894745e82fb107fc4a869a8832d86',1,'Steinberg::Vst::PlugProvider::PlugProvider()'],['../../vstsdk/classSteinberg_1_1Vst_1_1TestBase.html#aee0912e53e2d7f7ae563fad4e96c5d13',1,'Steinberg::Vst::TestBase::plugProvider()']]],
+  ['plugprovider',['plugProvider',['../../vstsdk/classSteinberg_1_1Vst_1_1TestBase.html#aee0912e53e2d7f7ae563fad4e96c5d13',1,'Steinberg::Vst::TestBase::plugProvider()'],['../../vstsdk/classSteinberg_1_1Vst_1_1PlugProvider.html#a020894745e82fb107fc4a869a8832d86',1,'Steinberg::Vst::PlugProvider::PlugProvider()']]],
   ['plugprovider',['PlugProvider',['../../vstsdk/classSteinberg_1_1Vst_1_1PlugProvider.html',1,'Steinberg::Vst']]],
   ['plugprovider_2ecpp',['plugprovider.cpp',['../../vstsdk/plugprovider_8cpp.html',1,'']]],
   ['plugprovider_2eh',['plugprovider.h',['../../vstsdk/plugprovider_8h.html',1,'']]],
@@ -105,7 +105,7 @@ var searchData=
   ['processcontext',['processContext',['../structSteinberg_1_1Vst_1_1ProcessData.html#ad27334aa1361d4ff3b139ca305bf1fad',1,'Steinberg::Vst::ProcessData']]],
   ['processcontext',['ProcessContext',['../structSteinberg_1_1Vst_1_1ProcessContext.html',1,'Steinberg::Vst']]],
   ['processcontextrequirements',['ProcessContextRequirements',['../../vstsdk/classSteinberg_1_1Vst_1_1ProcessContextRequirements.html',1,'Steinberg::Vst']]],
-  ['processcontextrequirements',['processContextRequirements',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html#acf51f81f4a57d1be775b5dd4ad64734b',1,'Steinberg::Vst::AudioEffect::processContextRequirements()'],['../../vstsdk/classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a2aaa8a8f65932a7e8157ef6a251ddd6f',1,'Steinberg::Vst::SingleComponentEffect::processContextRequirements()'],['../../vstsdk/classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#ae40c5b12ded747e7f7ab4d52bd7c8907',1,'Steinberg::Vst::ProcessContextRequirements::ProcessContextRequirements()']]],
+  ['processcontextrequirements',['ProcessContextRequirements',['../../vstsdk/classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#ae40c5b12ded747e7f7ab4d52bd7c8907',1,'Steinberg::Vst::ProcessContextRequirements::ProcessContextRequirements()'],['../../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html#acf51f81f4a57d1be775b5dd4ad64734b',1,'Steinberg::Vst::AudioEffect::processContextRequirements()'],['../../vstsdk/classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a2aaa8a8f65932a7e8157ef6a251ddd6f',1,'Steinberg::Vst::SingleComponentEffect::processContextRequirements()']]],
   ['processcontextrequirements_2eh',['processcontextrequirements.h',['../../vstsdk/processcontextrequirements_8h.html',1,'']]],
   ['processdata',['ProcessData',['../structSteinberg_1_1Vst_1_1ProcessData.html#a100f97803b72565daedee80e34bbb7f0',1,'Steinberg::Vst::ProcessData']]],
   ['processdata',['ProcessData',['../structSteinberg_1_1Vst_1_1ProcessData.html',1,'Steinberg::Vst']]],
@@ -134,7 +134,7 @@ var searchData=
   ['programlistwithpitchnames',['ProgramListWithPitchNames',['../../vstsdk/classSteinberg_1_1Vst_1_1ProgramListWithPitchNames.html#ac35cdc8c766d4de4e9677d278c01382a',1,'Steinberg::Vst::ProgramListWithPitchNames']]],
   ['programlistwithpitchnames',['ProgramListWithPitchNames',['../../vstsdk/classSteinberg_1_1Vst_1_1ProgramListWithPitchNames.html',1,'Steinberg::Vst']]],
   ['programnames',['programNames',['../../vstsdk/classSteinberg_1_1Vst_1_1ProgramList.html#a374d0d28218114229c2469dec596b9ff',1,'Steinberg::Vst::ProgramList']]],
-  ['programs',['programs',['../../vstsdk/structVST3_1_1Vst2xState.html#a69649642bc65a780bbab905b1c57aba7',1,'VST3::Vst2xState::programs()'],['../../vstsdk/structVST3_1_1Vst2xState.html#a6a250ebf1916f9297dbedc8fc488ddb4',1,'VST3::Vst2xState::Programs()']]],
+  ['programs',['Programs',['../../vstsdk/structVST3_1_1Vst2xState.html#a6a250ebf1916f9297dbedc8fc488ddb4',1,'VST3::Vst2xState::Programs()'],['../../vstsdk/structVST3_1_1Vst2xState.html#a69649642bc65a780bbab905b1c57aba7',1,'VST3::Vst2xState::programs()']]],
   ['programvalues',['ProgramValues',['../../vstsdk/structVST3_1_1Vst2xProgram.html#a2bc036956ebdabf74742defb97bee043',1,'VST3::Vst2xProgram']]],
   ['progresstype',['ProgressType',['../classSteinberg_1_1Vst_1_1IProgress.html#a69d16526a64609e721e3a65f3353d666',1,'Steinberg::Vst::IProgress']]],
   ['projecttimemusic',['projectTimeMusic',['../structSteinberg_1_1Vst_1_1ProcessContext.html#a4c1e16437e0c0858fa5288107e5b187f',1,'Steinberg::Vst::ProcessContext']]],
