@@ -6,5 +6,6 @@ var searchData=
   ['snapshot',['Snapshot',['../../vstsdk/structVST3_1_1Hosting_1_1Module_1_1Snapshot.html',1,'VST3::Hosting::Module']]],
   ['speakerarray',['SpeakerArray',['../../vstsdk/classSteinberg_1_1Vst_1_1SpeakerArray.html',1,'Steinberg::Vst']]],
   ['stringlistparameter',['StringListParameter',['../../vstsdk/classSteinberg_1_1Vst_1_1StringListParameter.html',1,'Steinberg::Vst']]],
-  ['stringresult',['StringResult',['../../vstsdk/exceptionSteinberg_1_1Vst_1_1StringResult.html',1,'Steinberg::Vst']]]
+  ['stringresult',['StringResult',['../../vstsdk/exceptionSteinberg_1_1Vst_1_1StringResult.html',1,'Steinberg::Vst']]],
+  ['systemtime',['SystemTime',['../../vstsdk/classSteinberg_1_1Vst_1_1SystemTime.html',1,'Steinberg::Vst']]]
 ];
