@@ -5,5 +5,7 @@ var searchData=
   ['settingsviewcontroller_2emm',['SettingsViewController.mm',['../../vstsdk/SettingsViewController_8mm.html',1,'']]],
   ['smartpointer_2eh',['smartpointer.h',['../../base/smartpointer_8h.html',1,'']]],
   ['stringconvert_2ecpp',['stringconvert.cpp',['../../vstsdk/stringconvert_8cpp.html',1,'']]],
-  ['stringconvert_2eh',['stringconvert.h',['../../vstsdk/stringconvert_8h.html',1,'']]]
+  ['stringconvert_2eh',['stringconvert.h',['../../vstsdk/stringconvert_8h.html',1,'']]],
+  ['systemtime_2ecpp',['systemtime.cpp',['../../vstsdk/systemtime_8cpp.html',1,'']]],
+  ['systemtime_2eh',['systemtime.h',['../../vstsdk/systemtime_8h.html',1,'']]]
 ];
