@@ -14,11 +14,13 @@ var searchData=
   ['isauro',['isAuro',['../group__speakerArrangements.html#gaa3a2c80faffa004172a77e983fd1d4ba',1,'Steinberg::Vst::SpeakerArr']]],
   ['isbundle',['isBundle',['../../vstsdk/classVST3_1_1Hosting_1_1Module.html#a732849e7293ae526d692dc14ca2faa5e',1,'VST3::Hosting::Module']]],
   ['isempty',['isEmpty',['../../base/classSteinberg_1_1FVariant.html#a479432127ee77145cc19d6a2d1590821',1,'Steinberg::FVariant']]],
-  ['isenabled',['isEnabled',['../../vstsdk/classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html#ae2931e09e0fd8eac15c83f0254b4e4ac',1,'Steinberg::Vst::InterAppAudio::MidiIO']]],
+  ['isenabled',['isEnabled',['../../vstsdk/classSteinberg_1_1Vst_1_1DataExchangeHandler.html#ae2931e09e0fd8eac15c83f0254b4e4ac',1,'Steinberg::Vst::DataExchangeHandler::isEnabled()'],['../../vstsdk/classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html#ae2931e09e0fd8eac15c83f0254b4e4ac',1,'Steinberg::Vst::InterAppAudio::MidiIO::isEnabled()']]],
+  ['ismainthread',['isMainThread',['../../vstsdk/structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost.html#acfcf2d0e7de13f022cb37b4391737aac',1,'Steinberg::Vst::IDataExchangeHandlerHost']]],
   ['ismidinetworkenabled',['isMidiNetworkEnabled',['../../vstsdk/classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html#a7440bcb5dab56eedbaa3fb9868e8488c',1,'Steinberg::Vst::InterAppAudio::MidiIO']]],
   ['isowner',['isOwner',['../../base/classSteinberg_1_1FVariant.html#a6c975d7981c86e14801166e34183eec7',1,'Steinberg::FVariant']]],
   ['isplatformtypesupported',['isPlatformTypeSupported',['../../base/classSteinberg_1_1IPlugView.html#abcfa60e135807caa316f3915622d9488',1,'Steinberg::IPlugView::isPlatformTypeSupported()'],['../../vstsdk/classSteinberg_1_1CPluginView.html#aa15dbd9a56fb4e4a168b9579b53f47bb',1,'Steinberg::CPluginView::isPlatformTypeSupported()'],['../../vstsdk/classSteinberg_1_1Vst_1_1VSTGUIEditor.html#aa15dbd9a56fb4e4a168b9579b53f47bb',1,'Steinberg::Vst::VSTGUIEditor::isPlatformTypeSupported()']]],
   ['ispluginterfacesupported',['isPlugInterfaceSupported',['../../vstsdk/classSteinberg_1_1Vst_1_1PlugInterfaceSupport.html#a1e255dede2eb780708771c99f881293f',1,'Steinberg::Vst::PlugInterfaceSupport::isPlugInterfaceSupported()'],['../classSteinberg_1_1Vst_1_1IPlugInterfaceSupport.html#acd41b87681c74169d1983afebc7fa3af',1,'Steinberg::Vst::IPlugInterfaceSupport::isPlugInterfaceSupported()']]],
+  ['isprocessorinactive',['isProcessorInactive',['../../vstsdk/structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost.html#adc46792f6bdea9aea38c76afb45b1302',1,'Steinberg::Vst::IDataExchangeHandlerHost']]],
   ['isstring',['isString',['../../base/classSteinberg_1_1FVariant.html#a3ea0b05483601e9acd735f48ccf7ed80',1,'Steinberg::FVariant']]],
   ['issubsetof',['isSubsetOf',['../group__speakerArrangements.html#gaf586d67f2382fd76829515ec1a845f0d',1,'Steinberg::Vst::SpeakerArr']]],
   ['isvalid',['isValid',['../../base/classSteinberg_1_1FUID.html#aac1b70a2ed67ead038c4d3f5ac4d8a81',1,'Steinberg::FUID']]],
