@@ -5,6 +5,9 @@ var classSteinberg_1_1Vst_1_1PlugProvider =
     [ "PlugProvider", "classSteinberg_1_1Vst_1_1PlugProvider.html#a020894745e82fb107fc4a869a8832d86", null ],
     [ "~PlugProvider", "classSteinberg_1_1Vst_1_1PlugProvider.html#a7f91cb0563a7c3753263b36530e624a1", null ],
     [ "initialize", "classSteinberg_1_1Vst_1_1PlugProvider.html#ab3e7cc706c522b3231f9156bba461436", null ],
+    [ "getComponentPtr", "classSteinberg_1_1Vst_1_1PlugProvider.html#ac1d983724401aaaae701bef957048a18", null ],
+    [ "getControllerPtr", "classSteinberg_1_1Vst_1_1PlugProvider.html#aae732f7daca82b6437d1f4480b528a4c", null ],
+    [ "getClassInfo", "classSteinberg_1_1Vst_1_1PlugProvider.html#a46683fbe97158d5c8ac47b14cc9f5d67", null ],
     [ "getComponent", "classSteinberg_1_1Vst_1_1PlugProvider.html#a7b48e5060e87f05aa6dbe009c49590b3", null ],
     [ "getController", "classSteinberg_1_1Vst_1_1PlugProvider.html#ab3729c4eddeab38f21f7e34ebd18dc25", null ],
     [ "releasePlugIn", "classSteinberg_1_1Vst_1_1PlugProvider.html#af532604d58ac09daa58a28f20af17ba4", null ],
