@@ -13,29 +13,29 @@ var NAVTREEINDEX0 =
 "HostApp_8h.html":[5,0,31],
 "HostApp_8mm.html":[5,0,32],
 "How.html":[1],
-"MidiIO_8h.html":[5,0,38],
-"MidiIO_8mm.html":[5,0,39],
-"NSDataIBStream_8h.html":[5,0,47],
-"NSDataIBStream_8mm.html":[5,0,48],
-"PresetBrowserViewController_8h.html":[5,0,58],
-"PresetBrowserViewController_8mm.html":[5,0,59],
-"PresetManager_8h.html":[5,0,60],
-"PresetManager_8mm.html":[5,0,61],
-"PresetSaveViewController_8h.html":[5,0,62],
-"PresetSaveViewController_8mm.html":[5,0,63],
-"SettingsViewController_8h.html":[5,0,71],
-"SettingsViewController_8h.html#a4deb5edab4ea5afce6e46372937444e2":[5,0,71,0],
-"SettingsViewController_8mm.html":[5,0,72],
-"SettingsViewController_8mm.html#a4deb5edab4ea5afce6e46372937444e2":[5,0,72,0],
-"VST3Editor_8h.html":[5,0,89],
-"VST3Editor_8mm.html":[5,0,90],
-"VST3Plugin_8h.html":[5,0,91],
-"VST3Plugin_8mm.html":[5,0,92],
-"VST3Plugin_8mm.html#a65451ddd317f3c796347114f42638024":[5,0,92,1],
-"VST3Plugin_8mm.html#a6763fb3bf363ffc54ee132d466c50297":[5,0,92,0],
-"VST3Plugin_8mm.html#ab2feb4fc133a7b3e0cdb5f9cdf941382":[5,0,92,2],
-"VSTInterAppAudioAppDelegateBase_8h.html":[5,0,112],
-"VSTInterAppAudioAppDelegateBase_8mm.html":[5,0,113],
+"MidiIO_8h.html":[5,0,39],
+"MidiIO_8mm.html":[5,0,40],
+"NSDataIBStream_8h.html":[5,0,48],
+"NSDataIBStream_8mm.html":[5,0,49],
+"PresetBrowserViewController_8h.html":[5,0,59],
+"PresetBrowserViewController_8mm.html":[5,0,60],
+"PresetManager_8h.html":[5,0,61],
+"PresetManager_8mm.html":[5,0,62],
+"PresetSaveViewController_8h.html":[5,0,63],
+"PresetSaveViewController_8mm.html":[5,0,64],
+"SettingsViewController_8h.html":[5,0,72],
+"SettingsViewController_8h.html#a4deb5edab4ea5afce6e46372937444e2":[5,0,72,0],
+"SettingsViewController_8mm.html":[5,0,73],
+"SettingsViewController_8mm.html#a4deb5edab4ea5afce6e46372937444e2":[5,0,73,0],
+"VST3Editor_8h.html":[5,0,90],
+"VST3Editor_8mm.html":[5,0,91],
+"VST3Plugin_8h.html":[5,0,92],
+"VST3Plugin_8mm.html":[5,0,93],
+"VST3Plugin_8mm.html#a65451ddd317f3c796347114f42638024":[5,0,93,1],
+"VST3Plugin_8mm.html#a6763fb3bf363ffc54ee132d466c50297":[5,0,93,0],
+"VST3Plugin_8mm.html#ab2feb4fc133a7b3e0cdb5f9cdf941382":[5,0,93,2],
+"VSTInterAppAudioAppDelegateBase_8h.html":[5,0,113],
+"VSTInterAppAudioAppDelegateBase_8mm.html":[5,0,114],
 "aaxentry_8cpp.html":[5,0,0],
 "aaxentry_8cpp.html#a11ef6f2b3053d009d2a02df2e8b91e4c":[5,0,0,0],
 "aaxentry_8cpp.html#a20ec2dc15aae43864287ac1324f7ae6a":[5,0,0,5],
@@ -138,6 +138,15 @@ var NAVTREEINDEX0 =
 "classSteinberg_1_1OneReaderOneWriter_1_1RingBuffer.html#a91f11a2997e9e08387ea391c50fc1e98":[4,0,0,2,0,4],
 "classSteinberg_1_1OneReaderOneWriter_1_1RingBuffer.html#aaf49963ae6d354927275c84adc3f448e":[4,0,0,2,0,2],
 "classSteinberg_1_1OneReaderOneWriter_1_1RingBuffer.html#abbabbc28c5f4f8830e2ed06b19ea9549":[4,0,0,2,0,3],
+"classSteinberg_1_1ResizableMemoryIBStream.html":[4,0,0,3],
+"classSteinberg_1_1ResizableMemoryIBStream.html#a04965610c741b207292115bd2f28f89e":[4,0,0,3,2],
+"classSteinberg_1_1ResizableMemoryIBStream.html#a2c4aa704d25afb5f0f793e653eda7337":[4,0,0,3,5],
+"classSteinberg_1_1ResizableMemoryIBStream.html#a3e008547e04bf044d144308628c08eaa":[4,0,0,3,0],
+"classSteinberg_1_1ResizableMemoryIBStream.html#a50fd45a16f261b03326a4142c3f3da03":[4,0,0,3,3],
+"classSteinberg_1_1ResizableMemoryIBStream.html#aa8a760d91a442deaa2cf5d0addd8176b":[4,0,0,3,6],
+"classSteinberg_1_1ResizableMemoryIBStream.html#ab8734e666421c9fe3b6380a818c6c727":[4,0,0,3,7],
+"classSteinberg_1_1ResizableMemoryIBStream.html#acbe865d4dee3f7291b82df7740283b94":[4,0,0,3,4],
+"classSteinberg_1_1ResizableMemoryIBStream.html#accfa4b843fc801b9e385bcebd1f91c1e":[4,0,0,3,1],
 "classSteinberg_1_1Vst_1_1AudioBuffer.html":[4,0,0,1,6],
 "classSteinberg_1_1Vst_1_1AudioBuffer.html#a0e03bfdc08a81457a0089d1fd9bd26b7":[4,0,0,1,6,1],
 "classSteinberg_1_1Vst_1_1AudioBuffer.html#a220bcc74548c37cf5fd56375433ab7d6":[4,0,0,1,6,3],
@@ -240,14 +249,5 @@ var NAVTREEINDEX0 =
 "classSteinberg_1_1Vst_1_1ComponentBase.html#a170e3042a5e695227c6931fba321debb":[2,0,6,11],
 "classSteinberg_1_1Vst_1_1ComponentBase.html#a272e5d4c8e24f012573f9f5b11f7f569":[2,0,6,10],
 "classSteinberg_1_1Vst_1_1ComponentBase.html#a4d588063b00a3115535657e9e34fdfee":[2,0,6,14],
-"classSteinberg_1_1Vst_1_1ComponentBase.html#a4dae123b5697706651d9ff20c9614f63":[2,0,6,9],
-"classSteinberg_1_1Vst_1_1ComponentBase.html#a60bbab8211ead54d50dbb672be410342":[2,0,6,13],
-"classSteinberg_1_1Vst_1_1ComponentBase.html#a6e27175ee5edbf22022daefbf19aceeb":[2,0,6,8],
-"classSteinberg_1_1Vst_1_1ComponentBase.html#a92accc56f3a2d30116b52b3f5948101b":[2,0,6,6],
-"classSteinberg_1_1Vst_1_1ComponentBase.html#a992af1025ac7720ce29a87d926531e05":[2,0,6,1],
-"classSteinberg_1_1Vst_1_1ComponentBase.html#aa3484053dd9d99fb072465f65ed3a58e":[2,0,6,5],
-"classSteinberg_1_1Vst_1_1ComponentBase.html#aae7bbbf07353224bb0ba77a091b87d33":[2,0,6,4],
-"classSteinberg_1_1Vst_1_1ComponentBase.html#ab3b1f8979c4bbe983e42010925959fd3":[2,0,6,0],
-"classSteinberg_1_1Vst_1_1ComponentBase.html#ab599093d44aa82deac5e46dba5cb8d18":[2,0,6,7],
-"classSteinberg_1_1Vst_1_1ComponentBase.html#adbcbdfd9061c4f951db444f60d358b12":[2,0,6,12]
+"classSteinberg_1_1Vst_1_1ComponentBase.html#a4dae123b5697706651d9ff20c9614f63":[2,0,6,9]
 };
