@@ -1,5 +1,14 @@
 var NAVTREEINDEX2 =
 {
+"classSteinberg_1_1Vst_1_1Parameter.html#adbfcb4b21973f6480502111f899ff8da":[2,0,17,6],
+"classSteinberg_1_1Vst_1_1Parameter.html#ae19c2c90f8dec6b6c96ff91b584c2b11":[2,0,17,17],
+"classSteinberg_1_1Vst_1_1Parameter.html#af3783cde85022795e4e6cfc78e627262":[2,0,17,15],
+"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html":[2,2,5],
+"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a03027b3181599682f2c0e1d099276726":[2,2,5,11],
+"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a2409ad0a1739756bcf2889765ee14938":[2,2,5,5],
+"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a40eebc46ee9addec3780f266037c642f":[2,2,5,10],
+"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a5bc38e228c5ff68f4193697272b90963":[2,2,5,6],
+"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a7ecbfd66175891f0d25dd3e70348e242":[2,2,5,8],
 "classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a7fdfae5a8e4484cd756f500d797d019b":[2,2,5,2],
 "classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a81daa8962de04d31bd39748347572b6f":[2,2,5,3],
 "classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a8eb5993e076e7fbac47a9713a8083fd0":[2,2,5,1],
@@ -52,28 +61,31 @@ var NAVTREEINDEX2 =
 "classSteinberg_1_1Vst_1_1PlugInterfaceSupport.html#af94a822c9390d013ab16bba205db47c2":[2,2,6,1],
 "classSteinberg_1_1Vst_1_1PlugProvider.html":[4,0,0,1,15],
 "classSteinberg_1_1Vst_1_1PlugProvider.html#a020894745e82fb107fc4a869a8832d86":[4,0,0,1,15,2],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a0c4daae75c9c796e333143d736bc766c":[4,0,0,1,15,19],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a0ff857240296663db1f7c55c057204e1":[4,0,0,1,15,14],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a12cbed77ca2d669e478a375473de6fb1":[4,0,0,1,15,13],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a131548654f635c364467a1dd563e6b85":[4,0,0,1,15,8],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a22bcbf7c186e8f0ecd486e31ee936461":[4,0,0,1,15,21],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a547929ce1c484ec21872a64c72d22882":[4,0,0,1,15,9],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a6049925777740077b65848662a42fd12":[4,0,0,1,15,12],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a6249cbd10d897a88d111a89c2ca6b6b6":[4,0,0,1,15,22],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a6e0a0488e3319db98db002bdce062d2b":[4,0,0,1,15,11],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a7b48e5060e87f05aa6dbe009c49590b3":[4,0,0,1,15,5],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a7ddbf523610d9a2456ef7b40f1ef488e":[4,0,0,1,15,16],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a0c4daae75c9c796e333143d736bc766c":[4,0,0,1,15,22],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a0ff857240296663db1f7c55c057204e1":[4,0,0,1,15,17],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a12cbed77ca2d669e478a375473de6fb1":[4,0,0,1,15,16],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a131548654f635c364467a1dd563e6b85":[4,0,0,1,15,11],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a22bcbf7c186e8f0ecd486e31ee936461":[4,0,0,1,15,24],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a46683fbe97158d5c8ac47b14cc9f5d67":[4,0,0,1,15,7],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a547929ce1c484ec21872a64c72d22882":[4,0,0,1,15,12],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a6049925777740077b65848662a42fd12":[4,0,0,1,15,15],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a6249cbd10d897a88d111a89c2ca6b6b6":[4,0,0,1,15,25],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a6e0a0488e3319db98db002bdce062d2b":[4,0,0,1,15,14],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a7b48e5060e87f05aa6dbe009c49590b3":[4,0,0,1,15,8],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a7ddbf523610d9a2456ef7b40f1ef488e":[4,0,0,1,15,19],
 "classSteinberg_1_1Vst_1_1PlugProvider.html#a7f91cb0563a7c3753263b36530e624a1":[4,0,0,1,15,3],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#ab3729c4eddeab38f21f7e34ebd18dc25":[4,0,0,1,15,6],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#aae732f7daca82b6437d1f4480b528a4c":[4,0,0,1,15,6],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#ab3729c4eddeab38f21f7e34ebd18dc25":[4,0,0,1,15,9],
 "classSteinberg_1_1Vst_1_1PlugProvider.html#ab3aa0d2066929e476a55a482d1fc30b6":[4,0,0,1,15,0],
 "classSteinberg_1_1Vst_1_1PlugProvider.html#ab3e7cc706c522b3231f9156bba461436":[4,0,0,1,15,4],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#ab89459e0f8333c820b84811bd128a7f7":[4,0,0,1,15,20],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#abda27e260ba5fd0a31f038d57e2fab17":[4,0,0,1,15,17],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#abfa14a169f62d20586d1d173d7af068c":[4,0,0,1,15,15],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#ab89459e0f8333c820b84811bd128a7f7":[4,0,0,1,15,23],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#abda27e260ba5fd0a31f038d57e2fab17":[4,0,0,1,15,20],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#abfa14a169f62d20586d1d173d7af068c":[4,0,0,1,15,18],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#ac1d983724401aaaae701bef957048a18":[4,0,0,1,15,5],
 "classSteinberg_1_1Vst_1_1PlugProvider.html#acb7f3ade3027a9b53397308800272789":[4,0,0,1,15,1],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#adec9a6f39ce77aa4383fef325929fb92":[4,0,0,1,15,18],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#ae1e194cb41fe51987a519a92abf23d3f":[4,0,0,1,15,10],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#af532604d58ac09daa58a28f20af17ba4":[4,0,0,1,15,7],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#adec9a6f39ce77aa4383fef325929fb92":[4,0,0,1,15,21],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#ae1e194cb41fe51987a519a92abf23d3f":[4,0,0,1,15,13],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#af532604d58ac09daa58a28f20af17ba4":[4,0,0,1,15,10],
 "classSteinberg_1_1Vst_1_1PluginContextFactory.html":[4,0,0,1,16],
 "classSteinberg_1_1Vst_1_1PluginContextFactory.html#a2400af6b76b72f7cfb23172352124110":[4,0,0,1,16,0],
 "classSteinberg_1_1Vst_1_1PluginContextFactory.html#a26bc7df45b240e136545ce1419b56a16":[4,0,0,1,16,1],
@@ -237,17 +249,5 @@ var NAVTREEINDEX2 =
 "classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a4dae123b5697706651d9ff20c9614f63":[2,0,23,2],
 "classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a5c45cf61d3d8331302cdc6cad9ba2b3d":[2,0,23,11],
 "classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a5c6f3bcf7a15be18c8e63a52aa6775dd":[2,0,23,1],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a65adc2e475dee42d4427686a20381160":[2,0,23,34],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a65dae22538ad6a22779884405a4490ed":[2,0,23,18],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a754f2c1b5beff1179b96278344f1ef96":[2,0,23,24],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a7af5768bbbab94f5a227313fff6ef74e":[2,0,23,8],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a82771278a563c17a20eaf97f8fb14311":[2,0,23,10],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a985dc60099827f0160cf03e294e3989b":[2,0,23,30],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a98a16757564b1a077d82e2b2decc2ad8":[2,0,23,15],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a9a162bdcd28aabf4f53dc808ffccfb94":[2,0,23,31],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#aac50582d4f3f12401ae426cc31b33287":[2,0,23,23],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#aae75b97c8b97b30648a3fbe8e3ecf942":[2,0,23,17],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#ab5393bfe75dac26ada3d2f33b5f372cf":[2,0,23,12],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#ac8369734067dcb5f9288a67db686e5f4":[2,0,23,4],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#acf5189a9e37c263015c22a7f81b750c8":[2,0,23,13]
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a65adc2e475dee42d4427686a20381160":[2,0,23,34]
 };
