@@ -1,5 +1,17 @@
 var NAVTREEINDEX3 =
 {
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a65dae22538ad6a22779884405a4490ed":[2,0,23,18],
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a754f2c1b5beff1179b96278344f1ef96":[2,0,23,24],
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a7af5768bbbab94f5a227313fff6ef74e":[2,0,23,8],
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a82771278a563c17a20eaf97f8fb14311":[2,0,23,10],
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a985dc60099827f0160cf03e294e3989b":[2,0,23,30],
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a98a16757564b1a077d82e2b2decc2ad8":[2,0,23,15],
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a9a162bdcd28aabf4f53dc808ffccfb94":[2,0,23,31],
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#aac50582d4f3f12401ae426cc31b33287":[2,0,23,23],
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#aae75b97c8b97b30648a3fbe8e3ecf942":[2,0,23,17],
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#ab5393bfe75dac26ada3d2f33b5f372cf":[2,0,23,12],
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#ac8369734067dcb5f9288a67db686e5f4":[2,0,23,4],
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#acf5189a9e37c263015c22a7f81b750c8":[2,0,23,13],
 "classSteinberg_1_1Vst_1_1SingleComponentEffect.html#adc3fc77f74a27de4c7238ffebda644bb":[2,0,23,5],
 "classSteinberg_1_1Vst_1_1SingleComponentEffect.html#adc63b47c5958e737abb364f126a7391f":[2,0,23,26],
 "classSteinberg_1_1Vst_1_1SingleComponentEffect.html#add6d889f0a8a72718b1ac12e049b55dc":[2,0,23,21],
@@ -223,8 +235,8 @@ var NAVTREEINDEX3 =
 "exceptionSteinberg_1_1Vst_1_1StringResult.html#aceeefd83ecd3c2384778ac88c22cf96b":[4,0,0,1,23,3],
 "exceptionSteinberg_1_1Vst_1_1StringResult.html#aed655be6be495be7869040dcdf77a0b3":[4,0,0,1,23,0],
 "files.html":[5,0],
-"functions.html":[4,3,0,0],
 "functions.html":[4,3,0],
+"functions.html":[4,3,0,0],
 "functions_0x62.html":[4,3,0,1],
 "functions_0x63.html":[4,3,0,2],
 "functions_0x64.html":[4,3,0,3],
@@ -237,17 +249,5 @@ var NAVTREEINDEX3 =
 "functions_0x6c.html":[4,3,0,10],
 "functions_0x6d.html":[4,3,0,11],
 "functions_0x6e.html":[4,3,0,12],
-"functions_0x6f.html":[4,3,0,13],
-"functions_0x70.html":[4,3,0,14],
-"functions_0x71.html":[4,3,0,15],
-"functions_0x72.html":[4,3,0,16],
-"functions_0x73.html":[4,3,0,17],
-"functions_0x74.html":[4,3,0,18],
-"functions_0x75.html":[4,3,0,19],
-"functions_0x76.html":[4,3,0,20],
-"functions_0x77.html":[4,3,0,21],
-"functions_0x78.html":[4,3,0,22],
-"functions_0x79.html":[4,3,0,23],
-"functions_0x7e.html":[4,3,0,24],
-"functions_enum.html":[4,3,4]
+"functions_0x6f.html":[4,3,0,13]
 };
