@@ -1,8 +1,20 @@
 var NAVTREEINDEX4 =
 {
+"functions_0x70.html":[4,3,0,14],
+"functions_0x71.html":[4,3,0,15],
+"functions_0x72.html":[4,3,0,16],
+"functions_0x73.html":[4,3,0,17],
+"functions_0x74.html":[4,3,0,18],
+"functions_0x75.html":[4,3,0,19],
+"functions_0x76.html":[4,3,0,20],
+"functions_0x77.html":[4,3,0,21],
+"functions_0x78.html":[4,3,0,22],
+"functions_0x79.html":[4,3,0,23],
+"functions_0x7e.html":[4,3,0,24],
+"functions_enum.html":[4,3,4],
 "functions_eval.html":[4,3,5],
-"functions_func.html":[4,3,1],
 "functions_func.html":[4,3,1,0],
+"functions_func.html":[4,3,1],
 "functions_func_0x62.html":[4,3,1,1],
 "functions_func_0x63.html":[4,3,1,2],
 "functions_func_0x64.html":[4,3,1,3],
@@ -59,61 +71,62 @@ var NAVTREEINDEX4 =
 "interfaceVSTInterAppAudioAppDelegateBase.html#adf97fa0e5331aac60fe36b12f941f922":[4,0,3,4],
 "interfaceVSTInterAppAudioAppDelegateBase.html#ae04748cdefebda525b266731b6c120a2":[4,0,3,6],
 "interfaceVSTInterAppAudioAppDelegateBase.html#af02564ed60997f25d5140e48a12124a7":[4,0,3,1],
-"memorystream_8h.html":[5,0,37],
-"module_8cpp.html":[5,0,40],
-"module_8h.html":[5,0,41],
-"module__linux_8cpp.html":[5,0,42],
-"module__linux_8cpp.html#a19968797a6fea0ed90fe831e4bf4f5bd":[5,0,42,4],
-"module__linux_8cpp.html#a71d82882268b976c5260a89577b9d2f9":[5,0,42,2],
-"module__linux_8cpp.html#a7f7123ffe9352ede10ecc711ae8901d3":[5,0,42,0],
-"module__linux_8cpp.html#a9b715f5fd5674dcf99d4b3b286f9c993":[5,0,42,1],
-"module__linux_8cpp.html#ada742d09a758c7053b346ceab75bfa58":[5,0,42,3],
-"module__mac_8mm.html":[5,0,43],
-"module__mac_8mm.html#a456f81687ab23bfa518d25165d688aa4":[5,0,43,2],
-"module__mac_8mm.html#a4646f121b3a9e74f96ecf21c6e24b4ec":[5,0,43,0],
-"module__mac_8mm.html#a506bad6939b58350ec480b5acbdee6c4":[5,0,43,1],
-"module__win32_8cpp.html":[5,0,44],
-"module__win32_8cpp.html#a41ef2c2b409468fd271243d107c85e12":[5,0,44,7],
-"module__win32_8cpp.html#a56b0f237e07f0782cc40b2e9f12d4a92":[5,0,44,5],
-"module__win32_8cpp.html#a8412a3c25d49cee5637408e60384ae2c":[5,0,44,0],
-"module__win32_8cpp.html#aab6af62131aad81d17d3b4afd9db334f":[5,0,44,1],
-"module__win32_8cpp.html#ab960ef10cf6ba5f66c273a348d70cef7":[5,0,44,4],
-"module__win32_8cpp.html#aba0050d0d9182386e51d25ec355f4f8d":[5,0,44,3],
-"module__win32_8cpp.html#adc18f3cbe8d2b92a8350abbed9157fab":[5,0,44,6],
-"module__win32_8cpp.html#af1ce76814dd30ab1a712aaee424a9525":[5,0,44,2],
+"memoryibstream_8h.html":[5,0,37],
+"memorystream_8h.html":[5,0,38],
+"module_8cpp.html":[5,0,41],
+"module_8h.html":[5,0,42],
+"module__linux_8cpp.html":[5,0,43],
+"module__linux_8cpp.html#a19968797a6fea0ed90fe831e4bf4f5bd":[5,0,43,4],
+"module__linux_8cpp.html#a71d82882268b976c5260a89577b9d2f9":[5,0,43,2],
+"module__linux_8cpp.html#a7f7123ffe9352ede10ecc711ae8901d3":[5,0,43,0],
+"module__linux_8cpp.html#a9b715f5fd5674dcf99d4b3b286f9c993":[5,0,43,1],
+"module__linux_8cpp.html#ada742d09a758c7053b346ceab75bfa58":[5,0,43,3],
+"module__mac_8mm.html":[5,0,44],
+"module__mac_8mm.html#a456f81687ab23bfa518d25165d688aa4":[5,0,44,2],
+"module__mac_8mm.html#a4646f121b3a9e74f96ecf21c6e24b4ec":[5,0,44,0],
+"module__mac_8mm.html#a506bad6939b58350ec480b5acbdee6c4":[5,0,44,1],
+"module__win32_8cpp.html":[5,0,45],
+"module__win32_8cpp.html#a41ef2c2b409468fd271243d107c85e12":[5,0,45,7],
+"module__win32_8cpp.html#a56b0f237e07f0782cc40b2e9f12d4a92":[5,0,45,5],
+"module__win32_8cpp.html#a8412a3c25d49cee5637408e60384ae2c":[5,0,45,0],
+"module__win32_8cpp.html#aab6af62131aad81d17d3b4afd9db334f":[5,0,45,1],
+"module__win32_8cpp.html#ab960ef10cf6ba5f66c273a348d70cef7":[5,0,45,4],
+"module__win32_8cpp.html#aba0050d0d9182386e51d25ec355f4f8d":[5,0,45,3],
+"module__win32_8cpp.html#adc18f3cbe8d2b92a8350abbed9157fab":[5,0,45,6],
+"module__win32_8cpp.html#af1ce76814dd30ab1a712aaee424a9525":[5,0,45,2],
 "modules.html":[2],
-"mpeprocessor_8cpp.html":[5,0,45],
-"mpeprocessor_8h.html":[5,0,46],
-"mpeprocessor_8h.html#a3e8994751b152f3d2c0b7af99d4bd825":[5,0,46,5],
-"mpeprocessor_8h.html#a4c50a079c1d1540bd8a979d731211afa":[5,0,46,8],
-"mpeprocessor_8h.html#a4c50a079c1d1540bd8a979d731211afaa02129bb861061d1a052c592e2dc6b383":[5,0,46,8,1],
-"mpeprocessor_8h.html#a4c50a079c1d1540bd8a979d731211afaa57cec4137b614c87cb4e24a3d003a3e0":[5,0,46,8,2],
-"mpeprocessor_8h.html#a4c50a079c1d1540bd8a979d731211afaa6adf97f83acf6453d4a6a4b1070f3754":[5,0,46,8,3],
-"mpeprocessor_8h.html#a4c50a079c1d1540bd8a979d731211afaaa78578c428179b490a0461e76ba5f319":[5,0,46,8,0],
-"mpeprocessor_8h.html#a4d7f55bab4770c518fc51d11680376ce":[5,0,46,9],
-"mpeprocessor_8h.html#a4d7f55bab4770c518fc51d11680376cea3711a2ce088455b63a78f9f8f5cfdb3e":[5,0,46,9,2],
-"mpeprocessor_8h.html#a4d7f55bab4770c518fc51d11680376cea68292a2609ab656038be0ec343841ed2":[5,0,46,9,4],
-"mpeprocessor_8h.html#a4d7f55bab4770c518fc51d11680376cea9804413280ca3d345c26aef19789dea2":[5,0,46,9,0],
-"mpeprocessor_8h.html#a4d7f55bab4770c518fc51d11680376ceac54b75a3718ef2d9a20d4383520837fb":[5,0,46,9,1],
-"mpeprocessor_8h.html#a4d7f55bab4770c518fc51d11680376cead0eed86b1606c722a91a0cb9e71305e6":[5,0,46,9,3],
-"mpeprocessor_8h.html#a7c60eb3978177e5b1583e38914401ec9":[5,0,46,6],
-"mpeprocessor_8h.html#ab38d25bdae264eebd969558d1a01425b":[5,0,46,7],
-"mpeprocessor_8h.html#ab4311216475ec4d94c471bb87ed1721e":[5,0,46,3],
-"mpeprocessor_8h.html#acc0ccc0e35cb8a064d3b1675fbef9d44":[5,0,46,4],
+"mpeprocessor_8cpp.html":[5,0,46],
+"mpeprocessor_8h.html":[5,0,47],
+"mpeprocessor_8h.html#a3e8994751b152f3d2c0b7af99d4bd825":[5,0,47,5],
+"mpeprocessor_8h.html#a4c50a079c1d1540bd8a979d731211afa":[5,0,47,8],
+"mpeprocessor_8h.html#a4c50a079c1d1540bd8a979d731211afaa02129bb861061d1a052c592e2dc6b383":[5,0,47,8,1],
+"mpeprocessor_8h.html#a4c50a079c1d1540bd8a979d731211afaa57cec4137b614c87cb4e24a3d003a3e0":[5,0,47,8,2],
+"mpeprocessor_8h.html#a4c50a079c1d1540bd8a979d731211afaa6adf97f83acf6453d4a6a4b1070f3754":[5,0,47,8,3],
+"mpeprocessor_8h.html#a4c50a079c1d1540bd8a979d731211afaaa78578c428179b490a0461e76ba5f319":[5,0,47,8,0],
+"mpeprocessor_8h.html#a4d7f55bab4770c518fc51d11680376ce":[5,0,47,9],
+"mpeprocessor_8h.html#a4d7f55bab4770c518fc51d11680376cea3711a2ce088455b63a78f9f8f5cfdb3e":[5,0,47,9,2],
+"mpeprocessor_8h.html#a4d7f55bab4770c518fc51d11680376cea68292a2609ab656038be0ec343841ed2":[5,0,47,9,4],
+"mpeprocessor_8h.html#a4d7f55bab4770c518fc51d11680376cea9804413280ca3d345c26aef19789dea2":[5,0,47,9,0],
+"mpeprocessor_8h.html#a4d7f55bab4770c518fc51d11680376ceac54b75a3718ef2d9a20d4383520837fb":[5,0,47,9,1],
+"mpeprocessor_8h.html#a4d7f55bab4770c518fc51d11680376cead0eed86b1606c722a91a0cb9e71305e6":[5,0,47,9,3],
+"mpeprocessor_8h.html#a7c60eb3978177e5b1583e38914401ec9":[5,0,47,6],
+"mpeprocessor_8h.html#ab38d25bdae264eebd969558d1a01425b":[5,0,47,7],
+"mpeprocessor_8h.html#ab4311216475ec4d94c471bb87ed1721e":[5,0,47,3],
+"mpeprocessor_8h.html#acc0ccc0e35cb8a064d3b1675fbef9d44":[5,0,47,4],
 "namespaceSteinberg_1_1OneReaderOneWriter.html":[3,0,0,2],
 "namespaceSteinberg_1_1OneReaderOneWriter.html":[4,0,0,2],
 "namespaceSteinberg_1_1Vst_1_1Algo.html":[3,0,0,1,0],
 "namespaceSteinberg_1_1Vst_1_1Algo.html":[4,0,0,1,0],
-"namespaceSteinberg_1_1Vst_1_1Helpers.html":[3,0,0,1,1],
 "namespaceSteinberg_1_1Vst_1_1Helpers.html":[4,0,0,1,1],
+"namespaceSteinberg_1_1Vst_1_1Helpers.html":[3,0,0,1,1],
 "namespaceSteinberg_1_1Vst_1_1InterAppAudio.html":[3,0,0,1,2],
 "namespaceSteinberg_1_1Vst_1_1InterAppAudio.html":[4,0,0,1,2],
-"namespaceSteinberg_1_1Vst_1_1MPE.html":[3,0,0,1,3],
 "namespaceSteinberg_1_1Vst_1_1MPE.html":[4,0,0,1,3],
+"namespaceSteinberg_1_1Vst_1_1MPE.html":[3,0,0,1,3],
 "namespaceSteinberg_1_1Vst_1_1SampleAccurate.html":[3,0,0,1,4],
 "namespaceSteinberg_1_1Vst_1_1SampleAccurate.html":[4,0,0,1,4],
-"namespaceSteinberg_1_1Vst_1_1Test.html":[4,0,0,1,5],
 "namespaceSteinberg_1_1Vst_1_1Test.html":[3,0,0,1,5],
+"namespaceSteinberg_1_1Vst_1_1Test.html":[4,0,0,1,5],
 "namespaceVST3.html":[3,0,1],
 "namespaceVST3.html":[4,0,1],
 "namespaceVST3_1_1Hosting.html":[3,0,1,0],
@@ -131,62 +144,62 @@ var NAVTREEINDEX4 =
 "namespacemembers_type.html":[3,1,3],
 "namespacemembers_vars.html":[3,1,2],
 "namespaces.html":[3,0],
-"objcclassbuilder_8h.html":[5,0,49],
-"optional_8h.html":[5,0,50],
+"objcclassbuilder_8h.html":[5,0,50],
+"optional_8h.html":[5,0,51],
 "pages.html":[],
-"parameterchanges_8cpp.html":[5,0,51],
-"parameterchanges_8cpp.html#a5924f4d90b379cf4ccb846aff8b64d88":[5,0,51,2],
-"parameterchanges_8cpp.html#a9599d04a145b093a9e253d564c6739f5":[5,0,51,1],
-"parameterchanges_8cpp.html#ae41776e5d40ac5a09f7c0d862b004157":[5,0,51,0],
-"parameterchanges_8h.html":[5,0,52],
-"pluginterfacesupport_8cpp.html":[5,0,53],
-"pluginterfacesupport_8h.html":[5,0,54],
-"pluginview_8h.html":[5,0,55],
-"plugprovider_8cpp.html":[5,0,56],
-"plugprovider_8h.html":[5,0,57],
-"processcontextrequirements_8h.html":[5,0,64],
-"processdata_8cpp.html":[5,0,65],
-"processdata_8h.html":[5,0,66],
-"processdataslicer_8h.html":[5,0,67],
-"ringbuffer_8h.html":[5,0,68],
-"rttransfer_8h.html":[5,0,69],
-"sampleaccurate_8h.html":[5,0,70],
-"stringconvert_8cpp.html":[5,0,73],
-"stringconvert_8cpp.html#a516c6fb6f3feea42db8958f97e146129":[5,0,73,2],
-"stringconvert_8cpp.html#a7b24e433664bafa3dd3f9357ec3f6c4d":[5,0,73,0],
-"stringconvert_8cpp.html#a931b7bcc1c22509766093e32f28d2e23":[5,0,73,3],
-"stringconvert_8cpp.html#ab16efb35664dd3b3202ebc37571ae369":[5,0,73,1],
-"stringconvert_8cpp.html#ab20bb6b50e97de71fea1897b45dca317":[5,0,73,6],
-"stringconvert_8cpp.html#abff8a368026b5ff872b48945fcf3113f":[5,0,73,5],
-"stringconvert_8cpp.html#ad0e56044e282dcac7890cbce544aa83f":[5,0,73,4],
-"stringconvert_8h.html":[5,0,74],
-"stringconvert_8h.html#a207e23e9cafce1b77acf9da2f72f2fc9":[5,0,74,7],
-"stringconvert_8h.html#a4057efa382a8c98391f469c2a6f98ac5":[5,0,74,8],
-"stringconvert_8h.html#a516c6fb6f3feea42db8958f97e146129":[5,0,74,2],
-"stringconvert_8h.html#a7b24e433664bafa3dd3f9357ec3f6c4d":[5,0,74,0],
-"stringconvert_8h.html#a931b7bcc1c22509766093e32f28d2e23":[5,0,74,3],
-"stringconvert_8h.html#ab16efb35664dd3b3202ebc37571ae369":[5,0,74,1],
-"stringconvert_8h.html#ab20bb6b50e97de71fea1897b45dca317":[5,0,74,6],
-"stringconvert_8h.html#abff8a368026b5ff872b48945fcf3113f":[5,0,74,5],
-"stringconvert_8h.html#ad0e56044e282dcac7890cbce544aa83f":[5,0,74,4],
-"structSteinberg_1_1ObjCClassBuilder.html":[4,0,0,5],
-"structSteinberg_1_1ObjCClassBuilder.html#a2209859c56ad409d8ce38867cffa9480":[4,0,0,5,5],
-"structSteinberg_1_1ObjCClassBuilder.html#a64333672f21fc912e2f71d1e76676b88":[4,0,0,5,1],
-"structSteinberg_1_1ObjCClassBuilder.html#a867a597c78baf1a1b6fc18042ef12879":[4,0,0,5,2],
-"structSteinberg_1_1ObjCClassBuilder.html#ac47fee14d4500cdd85d75644a36794f0":[4,0,0,5,0],
-"structSteinberg_1_1ObjCClassBuilder.html#ae7a89c11ef0f50756e3b096e6ea3c640":[4,0,0,5,4],
-"structSteinberg_1_1ObjCClassBuilder.html#af6b9e115a0c5bb623f99ce0d455ec32c":[4,0,0,5,3],
-"structSteinberg_1_1ObjCInstance.html":[4,0,0,4],
-"structSteinberg_1_1ObjCInstance.html#a40d1c81cfa49dd2dae47e5ee0a678046":[4,0,0,4,2],
-"structSteinberg_1_1ObjCInstance.html#a6ecc79aa4806e0f3bf894b850c626ec8":[4,0,0,4,1],
-"structSteinberg_1_1ObjCInstance.html#ac9a665bd38b225c0e9d00c3198001b46":[4,0,0,4,3],
-"structSteinberg_1_1ObjCInstance.html#af297da87bd0771fcecdc2f796385b5d1":[4,0,0,4,0],
-"structSteinberg_1_1ObjCVariable.html":[4,0,0,3],
-"structSteinberg_1_1ObjCVariable.html#a0f806efa754adc9f722b43aabba42dd4":[4,0,0,3,4],
-"structSteinberg_1_1ObjCVariable.html#a62cd47bc16e8d305970d9e2c5aca9b41":[4,0,0,3,0],
-"structSteinberg_1_1ObjCVariable.html#a8891dba5d2ac256aaaca45d90d358233":[4,0,0,3,2],
-"structSteinberg_1_1ObjCVariable.html#acba23b5edee4b4a64824b762c33b1e6e":[4,0,0,3,1],
-"structSteinberg_1_1ObjCVariable.html#adf7d2a42944bd9b618b2dc17f8a47202":[4,0,0,3,3],
+"parameterchanges_8cpp.html":[5,0,52],
+"parameterchanges_8cpp.html#a5924f4d90b379cf4ccb846aff8b64d88":[5,0,52,2],
+"parameterchanges_8cpp.html#a9599d04a145b093a9e253d564c6739f5":[5,0,52,1],
+"parameterchanges_8cpp.html#ae41776e5d40ac5a09f7c0d862b004157":[5,0,52,0],
+"parameterchanges_8h.html":[5,0,53],
+"pluginterfacesupport_8cpp.html":[5,0,54],
+"pluginterfacesupport_8h.html":[5,0,55],
+"pluginview_8h.html":[5,0,56],
+"plugprovider_8cpp.html":[5,0,57],
+"plugprovider_8h.html":[5,0,58],
+"processcontextrequirements_8h.html":[5,0,65],
+"processdata_8cpp.html":[5,0,66],
+"processdata_8h.html":[5,0,67],
+"processdataslicer_8h.html":[5,0,68],
+"ringbuffer_8h.html":[5,0,69],
+"rttransfer_8h.html":[5,0,70],
+"sampleaccurate_8h.html":[5,0,71],
+"stringconvert_8cpp.html":[5,0,74],
+"stringconvert_8cpp.html#a516c6fb6f3feea42db8958f97e146129":[5,0,74,2],
+"stringconvert_8cpp.html#a7b24e433664bafa3dd3f9357ec3f6c4d":[5,0,74,0],
+"stringconvert_8cpp.html#a931b7bcc1c22509766093e32f28d2e23":[5,0,74,3],
+"stringconvert_8cpp.html#ab16efb35664dd3b3202ebc37571ae369":[5,0,74,1],
+"stringconvert_8cpp.html#ab20bb6b50e97de71fea1897b45dca317":[5,0,74,6],
+"stringconvert_8cpp.html#abff8a368026b5ff872b48945fcf3113f":[5,0,74,5],
+"stringconvert_8cpp.html#ad0e56044e282dcac7890cbce544aa83f":[5,0,74,4],
+"stringconvert_8h.html":[5,0,75],
+"stringconvert_8h.html#a207e23e9cafce1b77acf9da2f72f2fc9":[5,0,75,7],
+"stringconvert_8h.html#a4057efa382a8c98391f469c2a6f98ac5":[5,0,75,8],
+"stringconvert_8h.html#a516c6fb6f3feea42db8958f97e146129":[5,0,75,2],
+"stringconvert_8h.html#a7b24e433664bafa3dd3f9357ec3f6c4d":[5,0,75,0],
+"stringconvert_8h.html#a931b7bcc1c22509766093e32f28d2e23":[5,0,75,3],
+"stringconvert_8h.html#ab16efb35664dd3b3202ebc37571ae369":[5,0,75,1],
+"stringconvert_8h.html#ab20bb6b50e97de71fea1897b45dca317":[5,0,75,6],
+"stringconvert_8h.html#abff8a368026b5ff872b48945fcf3113f":[5,0,75,5],
+"stringconvert_8h.html#ad0e56044e282dcac7890cbce544aa83f":[5,0,75,4],
+"structSteinberg_1_1ObjCClassBuilder.html":[4,0,0,6],
+"structSteinberg_1_1ObjCClassBuilder.html#a2209859c56ad409d8ce38867cffa9480":[4,0,0,6,5],
+"structSteinberg_1_1ObjCClassBuilder.html#a64333672f21fc912e2f71d1e76676b88":[4,0,0,6,1],
+"structSteinberg_1_1ObjCClassBuilder.html#a867a597c78baf1a1b6fc18042ef12879":[4,0,0,6,2],
+"structSteinberg_1_1ObjCClassBuilder.html#ac47fee14d4500cdd85d75644a36794f0":[4,0,0,6,0],
+"structSteinberg_1_1ObjCClassBuilder.html#ae7a89c11ef0f50756e3b096e6ea3c640":[4,0,0,6,4],
+"structSteinberg_1_1ObjCClassBuilder.html#af6b9e115a0c5bb623f99ce0d455ec32c":[4,0,0,6,3],
+"structSteinberg_1_1ObjCInstance.html":[4,0,0,5],
+"structSteinberg_1_1ObjCInstance.html#a40d1c81cfa49dd2dae47e5ee0a678046":[4,0,0,5,2],
+"structSteinberg_1_1ObjCInstance.html#a6ecc79aa4806e0f3bf894b850c626ec8":[4,0,0,5,1],
+"structSteinberg_1_1ObjCInstance.html#ac9a665bd38b225c0e9d00c3198001b46":[4,0,0,5,3],
+"structSteinberg_1_1ObjCInstance.html#af297da87bd0771fcecdc2f796385b5d1":[4,0,0,5,0],
+"structSteinberg_1_1ObjCVariable.html":[4,0,0,4],
+"structSteinberg_1_1ObjCVariable.html#a0f806efa754adc9f722b43aabba42dd4":[4,0,0,4,4],
+"structSteinberg_1_1ObjCVariable.html#a62cd47bc16e8d305970d9e2c5aca9b41":[4,0,0,4,0],
+"structSteinberg_1_1ObjCVariable.html#a8891dba5d2ac256aaaca45d90d358233":[4,0,0,4,2],
+"structSteinberg_1_1ObjCVariable.html#acba23b5edee4b4a64824b762c33b1e6e":[4,0,0,4,1],
+"structSteinberg_1_1ObjCVariable.html#adf7d2a42944bd9b618b2dc17f8a47202":[4,0,0,4,3],
 "structSteinberg_1_1Vst_1_1BypassProcessor_1_1Delay.html":[4,0,0,1,7,0],
 "structSteinberg_1_1Vst_1_1BypassProcessor_1_1Delay.html#a05a8c092918b02827815cc8af99e453e":[4,0,0,1,7,0,2],
 "structSteinberg_1_1Vst_1_1BypassProcessor_1_1Delay.html#a1a013a451f71921f677fc504173431e3":[4,0,0,1,7,0,1],
@@ -236,18 +249,5 @@ var NAVTREEINDEX4 =
 "structSteinberg_1_1Vst_1_1MPE_1_1Setup.html#a3aa194401051cda47d3169eb46c2b051":[4,0,0,1,3,1,1],
 "structSteinberg_1_1Vst_1_1MPE_1_1Setup.html#a41d3db3e3509219ca3a7e9143941e1fa":[4,0,0,1,3,1,4],
 "structSteinberg_1_1Vst_1_1MPE_1_1Setup.html#a649ebe6f770b9c8470108dcecce28a85":[4,0,0,1,3,1,0],
-"structSteinberg_1_1Vst_1_1MPE_1_1Setup.html#ac74d3877c4ed65e4dbd0b3ce6da64f5f":[4,0,0,1,3,1,3],
-"structSteinberg_1_1Vst_1_1MPE_1_1Setup.html#af8018e5cc3b8a139129c2b56514f1950":[4,0,0,1,3,1,5],
-"structSteinberg_1_1Vst_1_1ParameterChangeTransfer_1_1ParameterChange.html":[2,2,5,0],
-"structSteinberg_1_1Vst_1_1ParameterChangeTransfer_1_1ParameterChange.html#a35a8e8c7048fc190f19479b6210eaf08":[2,2,5,0,0],
-"structSteinberg_1_1Vst_1_1ParameterChangeTransfer_1_1ParameterChange.html#a9b2081be7783cb98c534aa1ff955ac5c":[2,2,5,0,2],
-"structSteinberg_1_1Vst_1_1ParameterChangeTransfer_1_1ParameterChange.html#aa6ba601b698690bf6790c48e072f966a":[2,2,5,0,1],
-"structSteinberg_1_1Vst_1_1ParameterValueQueue_1_1ParameterQueueValue.html":[2,2,3,0],
-"structSteinberg_1_1Vst_1_1ParameterValueQueue_1_1ParameterQueueValue.html#a2ed2bda3c88547ab0819915d57b1ae52":[2,2,3,0,0],
-"structSteinberg_1_1Vst_1_1ParameterValueQueue_1_1ParameterQueueValue.html#a9b2081be7783cb98c534aa1ff955ac5c":[2,2,3,0,2],
-"structSteinberg_1_1Vst_1_1ParameterValueQueue_1_1ParameterQueueValue.html#aa6ba601b698690bf6790c48e072f966a":[2,2,3,0,1],
-"structSteinberg_1_1Vst_1_1PresetFile_1_1Entry.html":[2,0,21,0],
-"structSteinberg_1_1Vst_1_1PresetFile_1_1Entry.html#a3695b4badbf1fecec9ceaad8ce6bdc50":[2,0,21,0,1],
-"structSteinberg_1_1Vst_1_1PresetFile_1_1Entry.html#a4d97ade18b0ed2a8ce09dae0b0b4d228":[2,0,21,0,0],
-"structSteinberg_1_1Vst_1_1PresetFile_1_1Entry.html#ab1758d5ff5bb8a9770c8c1e1b3b5b5f9":[2,0,21,0,2]
+"structSteinberg_1_1Vst_1_1MPE_1_1Setup.html#ac74d3877c4ed65e4dbd0b3ce6da64f5f":[4,0,0,1,3,1,3]
 };
