@@ -8,6 +8,7 @@ var searchData=
   ['haspitchnames',['hasPitchNames',['../classSteinberg_1_1Vst_1_1ProgramList.html#abcd21a0dc142da8852f0c14e8bc01dcf',1,'Steinberg::Vst::ProgramList::hasPitchNames()'],['../classSteinberg_1_1Vst_1_1ProgramListWithPitchNames.html#a64c521f40929f86cadce19cab89cf272',1,'Steinberg::Vst::ProgramListWithPitchNames::hasPitchNames()']]],
   ['hasprogrampitchnames',['hasProgramPitchNames',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IUnitInfo.html#a63c02601259d4e8690f26eefaad53195',1,'Steinberg::Vst::IUnitInfo::hasProgramPitchNames()'],['../classSteinberg_1_1Vst_1_1EditControllerEx1.html#a803746c6ff155524e28fe85754483a23',1,'Steinberg::Vst::EditControllerEx1::hasProgramPitchNames()']]],
   ['havepointsbeenread',['havePointsBeenRead',['../classSteinberg_1_1Vst_1_1ParamChanges.html#ad9ef33d81be2e39cc162a3ac4f9a8983',1,'Steinberg::Vst::ParamChanges']]],
+  ['hideiidbase',['HideIIDBase',['../../base/structSteinberg_1_1FUnknownImpl_1_1HideIIDBase.html',1,'Steinberg::FUnknownImpl']]],
   ['hlog',['HLOG',['../aaxwrapper_8cpp.html#aaa67275c53290bd99d516d4b9a5d7d76',1,'HLOG():&#160;aaxwrapper.cpp'],['../aaxwrapper__parameters_8cpp.html#aaa67275c53290bd99d516d4b9a5d7d76',1,'HLOG():&#160;aaxwrapper_parameters.cpp']]],
   ['host',['host',['../../vstinterfaces/structSteinberg_1_1Vst_1_1RepresentationInfo.html#a74766a169cd1c18bc001b99e1984a901',1,'Steinberg::Vst::RepresentationInfo']]],
   ['hostapp_2eh',['HostApp.h',['../HostApp_8h.html',1,'']]],
@@ -17,6 +18,10 @@ var searchData=
   ['hostattributelist',['HostAttributeList',['../exceptionSteinberg_1_1Vst_1_1HostAttributeList.html',1,'Steinberg::Vst']]],
   ['hostclasses_2ecpp',['hostclasses.cpp',['../hostclasses_8cpp.html',1,'']]],
   ['hostclasses_2eh',['hostclasses.h',['../hostclasses_8h.html',1,'']]],
+  ['hostdataexchangehandler',['HostDataExchangeHandler',['../structSteinberg_1_1Vst_1_1HostDataExchangeHandler.html#a72c00ee9d1c317e2075880659f34a399',1,'Steinberg::Vst::HostDataExchangeHandler']]],
+  ['hostdataexchangehandler',['HostDataExchangeHandler',['../structSteinberg_1_1Vst_1_1HostDataExchangeHandler.html',1,'Steinberg::Vst']]],
+  ['hostdataexchangehandler_2ecpp',['hostdataexchangehandler.cpp',['../hostdataexchangehandler_8cpp.html',1,'']]],
+  ['hostdataexchangehandler_2eh',['hostdataexchangehandler.h',['../hostdataexchangehandler_8h.html',1,'']]],
   ['hostknobmode',['hostKnobMode',['../classSteinberg_1_1Vst_1_1EditController.html#aec9109c6f108a19e1c9220fbe52cb903',1,'Steinberg::Vst::EditController']]],
   ['hostmessage',['HostMessage',['../exceptionSteinberg_1_1Vst_1_1HostMessage.html#abe5688697369115f0e7e72c362258a75',1,'Steinberg::Vst::HostMessage']]],
   ['hostmessage',['HostMessage',['../exceptionSteinberg_1_1Vst_1_1HostMessage.html',1,'Steinberg::Vst']]],
