@@ -101,7 +101,7 @@ var searchData=
   ['processcontext',['processContext',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessData.html#ad27334aa1361d4ff3b139ca305bf1fad',1,'Steinberg::Vst::ProcessData']]],
   ['processcontext',['ProcessContext',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html',1,'Steinberg::Vst']]],
   ['processcontextrequirements',['ProcessContextRequirements',['../classSteinberg_1_1Vst_1_1ProcessContextRequirements.html',1,'Steinberg::Vst']]],
-  ['processcontextrequirements',['ProcessContextRequirements',['../classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#ae40c5b12ded747e7f7ab4d52bd7c8907',1,'Steinberg::Vst::ProcessContextRequirements::ProcessContextRequirements()'],['../classSteinberg_1_1Vst_1_1AudioEffect.html#acf51f81f4a57d1be775b5dd4ad64734b',1,'Steinberg::Vst::AudioEffect::processContextRequirements()'],['../classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a2aaa8a8f65932a7e8157ef6a251ddd6f',1,'Steinberg::Vst::SingleComponentEffect::processContextRequirements()']]],
+  ['processcontextrequirements',['processContextRequirements',['../classSteinberg_1_1Vst_1_1AudioEffect.html#acf51f81f4a57d1be775b5dd4ad64734b',1,'Steinberg::Vst::AudioEffect::processContextRequirements()'],['../classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a2aaa8a8f65932a7e8157ef6a251ddd6f',1,'Steinberg::Vst::SingleComponentEffect::processContextRequirements()'],['../classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#ae40c5b12ded747e7f7ab4d52bd7c8907',1,'Steinberg::Vst::ProcessContextRequirements::ProcessContextRequirements()']]],
   ['processcontextrequirements_2eh',['processcontextrequirements.h',['../processcontextrequirements_8h.html',1,'']]],
   ['processdata',['ProcessData',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessData.html#a100f97803b72565daedee80e34bbb7f0',1,'Steinberg::Vst::ProcessData']]],
   ['processdata',['ProcessData',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessData.html',1,'Steinberg::Vst']]],
@@ -118,7 +118,7 @@ var searchData=
   ['processsetup',['ProcessSetup',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessSetup.html',1,'Steinberg::Vst']]],
   ['programcount',['programCount',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProgramListInfo.html#aa480d0c44ff2b505ebf3581427dd8c05',1,'Steinberg::Vst::ProgramListInfo']]],
   ['programdatasupported',['programDataSupported',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IProgramListData.html#abc46e67ff37c30223ab01b70fe49a2e3',1,'Steinberg::Vst::IProgramListData']]],
-  ['programindexmap',['ProgramIndexMap',['../classSteinberg_1_1Vst_1_1EditControllerEx1.html#a1926d11ac5eb67ab443e956596b136bf',1,'Steinberg::Vst::EditControllerEx1::ProgramIndexMap()'],['../classSteinberg_1_1Vst_1_1EditControllerEx1.html#adff4e706a786b881134df97ce6755050',1,'Steinberg::Vst::EditControllerEx1::programIndexMap()']]],
+  ['programindexmap',['programIndexMap',['../classSteinberg_1_1Vst_1_1EditControllerEx1.html#adff4e706a786b881134df97ce6755050',1,'Steinberg::Vst::EditControllerEx1::programIndexMap()'],['../classSteinberg_1_1Vst_1_1EditControllerEx1.html#a1926d11ac5eb67ab443e956596b136bf',1,'Steinberg::Vst::EditControllerEx1::ProgramIndexMap()']]],
   ['programinfos',['programInfos',['../classSteinberg_1_1Vst_1_1ProgramList.html#a932cfb942e9ea765480dbd9524fed209',1,'Steinberg::Vst::ProgramList']]],
   ['programinfovector',['ProgramInfoVector',['../classSteinberg_1_1Vst_1_1ProgramList.html#a43790e03c786a44ac4501bf277e660e6',1,'Steinberg::Vst::ProgramList']]],
   ['programlist',['ProgramList',['../classSteinberg_1_1Vst_1_1ProgramList.html#a064d4941eb4a37a951ba11db619139a1',1,'Steinberg::Vst::ProgramList::ProgramList(const String128 name, ProgramListID listId, UnitID unitId)'],['../classSteinberg_1_1Vst_1_1ProgramList.html#af096804513689f8f3e210b22c69df785',1,'Steinberg::Vst::ProgramList::ProgramList(const ProgramList &amp;programList)']]],
@@ -134,6 +134,6 @@ var searchData=
   ['progresstype',['ProgressType',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IProgress.html#a69d16526a64609e721e3a65f3353d666',1,'Steinberg::Vst::IProgress']]],
   ['projecttimemusic',['projectTimeMusic',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html#a4c1e16437e0c0858fa5288107e5b187f',1,'Steinberg::Vst::ProcessContext']]],
   ['projecttimesamples',['projectTimeSamples',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html#a359d649ae34734b9876ad5a6a2f691f7',1,'Steinberg::Vst::ProcessContext']]],
-  ['ptr',['Ptr',['../classVST3_1_1Hosting_1_1Module.html#a6b597424e1e3214bbaa370140e784b15',1,'VST3::Hosting::Module::Ptr()'],['../../base/classSteinberg_1_1IPtr.html#a7c145f458643ff993b929f236d4a2ac0',1,'Steinberg::FUnknownPtr::ptr()'],['../vst2persistence_8cpp.html#ab6679b8a3625461c4f6c523048234022',1,'ptr():&#160;vst2persistence.cpp']]],
+  ['ptr',['ptr',['../../base/classSteinberg_1_1IPtr.html#a7c145f458643ff993b929f236d4a2ac0',1,'Steinberg::FUnknownPtr::ptr()'],['../classVST3_1_1Hosting_1_1Module.html#a6b597424e1e3214bbaa370140e784b15',1,'VST3::Hosting::Module::Ptr()'],['../vst2persistence_8cpp.html#ab6679b8a3625461c4f6c523048234022',1,'ptr():&#160;vst2persistence.cpp']]],
   ['push',['push',['../classSteinberg_1_1OneReaderOneWriter_1_1RingBuffer.html#abbabbc28c5f4f8830e2ed06b19ea9549',1,'Steinberg::OneReaderOneWriter::RingBuffer::push(ItemT &amp;&amp;item) noexcept'],['../classSteinberg_1_1OneReaderOneWriter_1_1RingBuffer.html#a91f11a2997e9e08387ea391c50fc1e98',1,'Steinberg::OneReaderOneWriter::RingBuffer::push(const ItemT &amp;item) noexcept']]]
 ];
