@@ -3,5 +3,7 @@ var searchData=
   ['queryinterface',['queryInterface',['../../base/classSteinberg_1_1FUnknown.html#a4199134d0669bfa92b7419dac14c01a7',1,'Steinberg::FUnknown::queryInterface()'],['../../base/classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFf7a30786d3fc5dff0954bd69a280ab56.html#a55024c93e14c692864229af868276a77',1,'Steinberg::FUnknownImpl::ImplementsImpl&lt; BaseClass, Directly&lt; I, DirectIFs...&gt;, Indirectly&lt; IndirectIFs...&gt; &gt;::queryInterface()'],['../../base/structSteinberg_1_1FUnknownImpl_1_1Detail_1_1QueryInterfaceEnd.html#a059fa2d166096ec12e0dc3aa9aa3fca1',1,'Steinberg::FUnknownImpl::Detail::QueryInterfaceEnd::queryInterface()'],['../exceptionSteinberg_1_1Vst_1_1StringResult.html#a5846f06504dc4625283cd31b524a5f1c',1,'Steinberg::Vst::StringResult::queryInterface()']]],
   ['queryinterfaceend',['QueryInterfaceEnd',['../../base/structSteinberg_1_1FUnknownImpl_1_1Detail_1_1QueryInterfaceEnd.html',1,'Steinberg::FUnknownImpl::Detail']]],
   ['queue',['queue',['../../base/classSteinberg_1_1IAttributes.html#a1c72961487139a9f07d9f78f694ad406',1,'Steinberg::IAttributes']]],
+  ['queueclosed',['queueClosed',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html#a37b2181ff0ae9bdc0a6feee03b65df42',1,'Steinberg::Vst::IDataExchangeReceiver']]],
+  ['queueopened',['queueOpened',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html#a0145a4f12f524bb3f9bfe42cb66ad27c',1,'Steinberg::Vst::IDataExchangeReceiver']]],
   ['queues',['queues',['../classSteinberg_1_1Vst_1_1ParameterChanges.html#acfb73c5aee1d941dc8bd1ddbe81a257b',1,'Steinberg::Vst::ParameterChanges']]]
 ];
