@@ -4,7 +4,7 @@ var searchData=
   ['tag',['tag',['../../vstinterfaces/structSteinberg_1_1Vst_1_1IContextMenuItem.html#a7cba719b5e6843c30b66241e6181688b',1,'Steinberg::Vst::IContextMenuItem']]],
   ['take',['take',['../../base/classSteinberg_1_1IPtr.html#ad23e3081bab74289f4472701b2707ad3',1,'Steinberg::FUnknownPtr::take()'],['../../base/classSteinberg_1_1IString.html#a278b6bc34d672210e69dbde261f52cab',1,'Steinberg::IString::take()']]],
   ['teardown',['teardown',['../../vstinterfaces/classSteinberg_1_1ITest.html#a47a53344d6db1006db6f4008102ae437',1,'Steinberg::ITest::teardown()'],['../classSteinberg_1_1Vst_1_1TestBase.html#a3d1fb91255e41edeeaee8794cd488720',1,'Steinberg::Vst::TestBase::teardown()'],['../classSteinberg_1_1Vst_1_1TestEnh.html#a3d1fb91255e41edeeaee8794cd488720',1,'Steinberg::Vst::TestEnh::teardown()']]],
-  ['tell',['tell',['../../base/classSteinberg_1_1IBStream.html#a25dc574e08d9d76e0c2805bb2f30f7ba',1,'Steinberg::IBStream::tell()'],['../classSteinberg_1_1Vst_1_1FileStream.html#a7a35b7508308b7cb624562821c653c84',1,'Steinberg::Vst::FileStream::tell()'],['../classSteinberg_1_1Vst_1_1ReadOnlyBStream.html#a7a35b7508308b7cb624562821c653c84',1,'Steinberg::Vst::ReadOnlyBStream::tell()'],['../classSteinberg_1_1Vst_1_1BufferStream.html#a7a35b7508308b7cb624562821c653c84',1,'Steinberg::Vst::BufferStream::tell()'],['../classSteinberg_1_1MemoryStream.html#a7a35b7508308b7cb624562821c653c84',1,'Steinberg::MemoryStream::tell()']]],
+  ['tell',['tell',['../../base/classSteinberg_1_1IBStream.html#a25dc574e08d9d76e0c2805bb2f30f7ba',1,'Steinberg::IBStream::tell()'],['../classSteinberg_1_1Vst_1_1FileStream.html#a7a35b7508308b7cb624562821c653c84',1,'Steinberg::Vst::FileStream::tell()'],['../classSteinberg_1_1Vst_1_1ReadOnlyBStream.html#a7a35b7508308b7cb624562821c653c84',1,'Steinberg::Vst::ReadOnlyBStream::tell()'],['../classSteinberg_1_1Vst_1_1BufferStream.html#a7a35b7508308b7cb624562821c653c84',1,'Steinberg::Vst::BufferStream::tell()'],['../classSteinberg_1_1ResizableMemoryIBStream.html#acbe865d4dee3f7291b82df7740283b94',1,'Steinberg::ResizableMemoryIBStream::tell()'],['../classSteinberg_1_1MemoryStream.html#a7a35b7508308b7cb624562821c653c84',1,'Steinberg::MemoryStream::tell()']]],
   ['tempo',['tempo',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html#aff2f6d52166217d13f9b2072c9e67c13',1,'Steinberg::Vst::ProcessContext']]],
   ['terminate',['terminate',['../../base/classSteinberg_1_1IPluginBase.html#a1563a6e0e622483924e5f21242407f16',1,'Steinberg::IPluginBase::terminate()'],['../classSteinberg_1_1Vst_1_1Component.html#a272e5d4c8e24f012573f9f5b11f7f569',1,'Steinberg::Vst::Component::terminate()'],['../classSteinberg_1_1Vst_1_1ComponentBase.html#a272e5d4c8e24f012573f9f5b11f7f569',1,'Steinberg::Vst::ComponentBase::terminate()'],['../classSteinberg_1_1Vst_1_1EditController.html#a272e5d4c8e24f012573f9f5b11f7f569',1,'Steinberg::Vst::EditController::terminate()'],['../classSteinberg_1_1Vst_1_1EditControllerEx1.html#a272e5d4c8e24f012573f9f5b11f7f569',1,'Steinberg::Vst::EditControllerEx1::terminate()'],['../classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a272e5d4c8e24f012573f9f5b11f7f569',1,'Steinberg::Vst::SingleComponentEffect::terminate()']]],
   ['terminateplugin',['terminatePlugin',['../classSteinberg_1_1Vst_1_1PlugProvider.html#a0ff857240296663db1f7c55c057204e1',1,'Steinberg::Vst::PlugProvider']]],
