@@ -1,8 +1,10 @@
 var searchData=
 [
   ['handler',['Handler',['../structSteinberg_1_1Vst_1_1MPE_1_1Handler.html',1,'Steinberg::Vst::MPE']]],
+  ['hideiidbase',['HideIIDBase',['../../base/structSteinberg_1_1FUnknownImpl_1_1HideIIDBase.html',1,'Steinberg::FUnknownImpl']]],
   ['hostapplication',['HostApplication',['../classSteinberg_1_1Vst_1_1HostApplication.html',1,'Steinberg::Vst']]],
   ['hostattributelist',['HostAttributeList',['../exceptionSteinberg_1_1Vst_1_1HostAttributeList.html',1,'Steinberg::Vst']]],
+  ['hostdataexchangehandler',['HostDataExchangeHandler',['../structSteinberg_1_1Vst_1_1HostDataExchangeHandler.html',1,'Steinberg::Vst']]],
   ['hostmessage',['HostMessage',['../exceptionSteinberg_1_1Vst_1_1HostMessage.html',1,'Steinberg::Vst']]],
   ['hostprocessdata',['HostProcessData',['../classSteinberg_1_1Vst_1_1HostProcessData.html',1,'Steinberg::Vst']]]
 ];
