@@ -4,6 +4,5 @@ var searchData=
   ['objcinstance',['ObjCInstance',['../structSteinberg_1_1ObjCInstance.html',1,'Steinberg']]],
   ['objcvariable',['ObjCVariable',['../structSteinberg_1_1ObjCVariable.html',1,'Steinberg']]],
   ['optional',['Optional',['../structVST3_1_1Optional.html',1,'VST3']]],
-  ['optr',['OPtr',['../../base/classSteinberg_1_1OPtr.html',1,'Steinberg']]],
-  ['optr_3c_20steinberg_3a_3avst_3a_3aconnectionproxy_20_3e',['OPtr&lt; Steinberg::Vst::ConnectionProxy &gt;',['../../base/classSteinberg_1_1OPtr.html',1,'Steinberg']]]
+  ['optr',['OPtr',['../../base/classSteinberg_1_1OPtr.html',1,'Steinberg']]]
 ];
