@@ -6,5 +6,6 @@ var searchData=
   ['snapshot',['Snapshot',['../structVST3_1_1Hosting_1_1Module_1_1Snapshot.html',1,'VST3::Hosting::Module']]],
   ['speakerarray',['SpeakerArray',['../classSteinberg_1_1Vst_1_1SpeakerArray.html',1,'Steinberg::Vst']]],
   ['stringlistparameter',['StringListParameter',['../classSteinberg_1_1Vst_1_1StringListParameter.html',1,'Steinberg::Vst']]],
-  ['stringresult',['StringResult',['../exceptionSteinberg_1_1Vst_1_1StringResult.html',1,'Steinberg::Vst']]]
+  ['stringresult',['StringResult',['../exceptionSteinberg_1_1Vst_1_1StringResult.html',1,'Steinberg::Vst']]],
+  ['systemtime',['SystemTime',['../classSteinberg_1_1Vst_1_1SystemTime.html',1,'Steinberg::Vst']]]
 ];
