@@ -12,11 +12,13 @@ var searchData=
   ['isattached',['isAttached',['../classSteinberg_1_1CPluginView.html#a1b7f04ee36bdaecd09a2625370dc90d8',1,'Steinberg::CPluginView']]],
   ['isbundle',['isBundle',['../classVST3_1_1Hosting_1_1Module.html#a732849e7293ae526d692dc14ca2faa5e',1,'VST3::Hosting::Module']]],
   ['isempty',['isEmpty',['../../base/classSteinberg_1_1FVariant.html#a479432127ee77145cc19d6a2d1590821',1,'Steinberg::FVariant']]],
-  ['isenabled',['isEnabled',['../classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html#ae2931e09e0fd8eac15c83f0254b4e4ac',1,'Steinberg::Vst::InterAppAudio::MidiIO']]],
+  ['isenabled',['isEnabled',['../classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html#ae2931e09e0fd8eac15c83f0254b4e4ac',1,'Steinberg::Vst::InterAppAudio::MidiIO::isEnabled()'],['../classSteinberg_1_1Vst_1_1DataExchangeHandler.html#ae2931e09e0fd8eac15c83f0254b4e4ac',1,'Steinberg::Vst::DataExchangeHandler::isEnabled()']]],
+  ['ismainthread',['isMainThread',['../structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost.html#acfcf2d0e7de13f022cb37b4391737aac',1,'Steinberg::Vst::IDataExchangeHandlerHost']]],
   ['ismidinetworkenabled',['isMidiNetworkEnabled',['../classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html#a7440bcb5dab56eedbaa3fb9868e8488c',1,'Steinberg::Vst::InterAppAudio::MidiIO']]],
   ['isowner',['isOwner',['../../base/classSteinberg_1_1FVariant.html#a6c975d7981c86e14801166e34183eec7',1,'Steinberg::FVariant']]],
   ['isplatformtypesupported',['isPlatformTypeSupported',['../../base/classSteinberg_1_1IPlugView.html#abcfa60e135807caa316f3915622d9488',1,'Steinberg::IPlugView::isPlatformTypeSupported()'],['../classSteinberg_1_1Vst_1_1VSTGUIEditor.html#aa15dbd9a56fb4e4a168b9579b53f47bb',1,'Steinberg::Vst::VSTGUIEditor::isPlatformTypeSupported()'],['../classSteinberg_1_1CPluginView.html#aa15dbd9a56fb4e4a168b9579b53f47bb',1,'Steinberg::CPluginView::isPlatformTypeSupported()']]],
   ['ispluginterfacesupported',['isPlugInterfaceSupported',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IPlugInterfaceSupport.html#acd41b87681c74169d1983afebc7fa3af',1,'Steinberg::Vst::IPlugInterfaceSupport::isPlugInterfaceSupported()'],['../classSteinberg_1_1Vst_1_1PlugInterfaceSupport.html#a1e255dede2eb780708771c99f881293f',1,'Steinberg::Vst::PlugInterfaceSupport::isPlugInterfaceSupported()']]],
+  ['isprocessorinactive',['isProcessorInactive',['../structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost.html#adc46792f6bdea9aea38c76afb45b1302',1,'Steinberg::Vst::IDataExchangeHandlerHost']]],
   ['isprojectstate',['isProjectState',['../namespaceSteinberg_1_1Vst_1_1Helpers.html#a7f02c298f47c0db9090be5aacb05f57b',1,'Steinberg::Vst::Helpers']]],
   ['issilent32',['isSilent32',['../namespaceSteinberg_1_1Vst_1_1Algo.html#ad3fbbf9aba45d6d78acc406f7177ddd2',1,'Steinberg::Vst::Algo']]],
   ['issilent64',['isSilent64',['../namespaceSteinberg_1_1Vst_1_1Algo.html#ab9a15d2a72d5500380bb5fa49551abf3',1,'Steinberg::Vst::Algo']]],
